@@ -1,6 +1,6 @@
 # ==========================================================================
 #
-# ZoneMinder Trigger Channel Handle Module, $Date: 2008-07-25 10:48:16 +0100 (Fri, 25 Jul 2008) $, $Revision: 2612 $
+# ZoneMinder Trigger Channel Handle Module, $Date: 2011-01-05 17:33:45 +0000 (Wed, 05 Jan 2011) $, $Revision: 3220 $
 # Copyright (C) 2001-2008  Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
@@ -69,6 +69,24 @@ sub open()
 	$self->{handle} = *sfh;
 }
 
+sub _spawn( $ )
+{
+    my $self = shift;
+    my $new_handle = shift;
+    my $clone = $self->clone();
+    $clone->{handle} = $new_handle;
+    $clone->{state} = 'connected';
+    return( $clone );
+}
+
+sub accept()
+{
+    my $self = shift;
+    local *cfh;
+    my $paddr = accept( *cfh, $self->{handle} );
+    return( $self->_spawn( *cfh ) );
+}
+
 1;
 __END__
 # Below is stub documentation for your module. You'd better edit it!
