@@ -1,5 +1,5 @@
 //
-// ZoneMinder Core Interfaces, $Date: 2008-07-25 10:23:20 +0100 (Fri, 25 Jul 2008) $, $Revision: 2610 $
+// ZoneMinder Core Interfaces, $Date: 2011-02-15 11:18:41 +0000 (Tue, 15 Feb 2011) $, $Revision: 3301 $
 // $Copyright$
 // 
 // This program is free software; you can redistribute it and/or
@@ -34,14 +34,6 @@ double round(double);
 #endif
 }
 
-typedef unsigned char       U8;
-typedef unsigned short      U16;
-typedef unsigned long       U32;
-typedef unsigned long long  U64;
-
-typedef signed char         S8;
-typedef signed short        S16;
-typedef signed long         S32;
-typedef signed long long    S64;
+#include <stdint.h>
 
 #endif // ZM_H
