@@ -1,5 +1,5 @@
 //
-// ZoneMinder Configuration Implementation, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// ZoneMinder Configuration Implementation, $Date: 2010-11-11 12:22:35 +0000 (Thu, 11 Nov 2010) $, $Revision: 3189 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -236,9 +236,9 @@ Config::~Config()
 
 void Config::Load()
 {
-	static char sql[BUFSIZ];
-
-	strncpy( sql, "select Name, Value, Type from Config order by Id", sizeof(sql) );
+    static char sql[ZM_SQL_SML_BUFSIZ];
+   
+    strncpy( sql, "select Name, Value, Type from Config order by Id", sizeof(sql) );
 	if ( mysql_query( &dbconn, sql ) )
 	{
 		Error( "Can't run query: %s", mysql_error( &dbconn ) );
