@@ -43,13 +43,24 @@ FfmpegCamera::FfmpegCamera( int p_id, const std::string &p_path, int p_width, in
 
 FfmpegCamera::~FfmpegCamera()
 {
-    av_free( mFrame );
-    av_free( mRawFrame );
+    av_freep( &mFrame );
+    av_freep( &mRawFrame );
     
-    avcodec_close( mCodecContext );
-    av_free( mCodecContext );
-    av_close_input_file( mFormatContext );
-    av_free( mFormatContext );
+    if ( mConvertContext )
+    {
+        sws_freeContext( mConvertContext );
+        mConvertContext = NULL;
+    }
+    if ( mCodecContext )
+    {
+       avcodec_close( mCodecContext );
+       mCodecContext = NULL; // Freed by av_close_input_file
+    }
+    if ( mFormatContext )
+    {
+        av_close_input_file( mFormatContext );
+        mFormatContext = NULL;
+    }
 
 	if ( capture )
 	{
@@ -63,7 +74,7 @@ void FfmpegCamera::Initialise()
 
 	mBuffer.size( max_size );
 
-    if ( zm_dbg_level > ZM_DBG_INF )
+    if ( zmDbgLevel > ZM_DBG_INF )
         av_log_set_level( AV_LOG_DEBUG ); 
     else
         av_log_set_level( AV_LOG_QUIET ); 
@@ -91,7 +102,11 @@ int FfmpegCamera::PrimeCapture()
     mVideoStreamId = -1;
     for ( int i=0; i < mFormatContext->nb_streams; i++ )
     {
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(51,2,1)
+        if ( mFormatContext->streams[i]->codec->codec_type == AVMEDIA_TYPE_VIDEO )
+#else
         if ( mFormatContext->streams[i]->codec->codec_type == CODEC_TYPE_VIDEO )
+#endif
         {
             mVideoStreamId = i;
             break;
@@ -143,12 +158,18 @@ int FfmpegCamera::Capture( Image &image )
     static int frameCount = 0;
     AVPacket packet;
     int frameComplete = false;
-    while ( !frameComplete && (av_read_frame( mFormatContext, &packet ) >= 0) )
+    while ( !frameComplete )
     {
+        int avResult = av_read_frame( mFormatContext, &packet );
+        if ( avResult < 0 )
+        {
+            Error( "Unable to read packet from stream %d: error %d", packet.stream_index, avResult );
+            return( -1 );
+        }
         Debug( 5, "Got packet from stream %d", packet.stream_index );
         if ( packet.stream_index == mVideoStreamId )
         {
-            if ( avcodec_decode_video( mCodecContext, mRawFrame, &frameComplete, packet.data, packet.size) < 0 )
+            if ( avcodec_decode_video2( mCodecContext, mRawFrame, &frameComplete, &packet ) < 0 )
                 Fatal( "Unable to decode frame at frame %d", frameCount );
 
             Debug( 3, "Decoded video packet at frame %d", frameCount );
