@@ -1,5 +1,5 @@
 //
-// ZoneMinder Image Class Implementation, $Date: 2009-05-25 19:03:46 +0100 (Mon, 25 May 2009) $, $Revision: 2890 $
+// ZoneMinder Image Class Implementation, $Date: 2011-02-15 11:18:41 +0000 (Tue, 15 Feb 2011) $, $Revision: 3301 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -67,7 +67,7 @@ Image::Image( const char *filename )
     text[0] = '\0';
 }
 
-Image::Image( int p_width, int p_height, int p_colours, JSAMPLE *p_buffer )
+Image::Image( int p_width, int p_height, int p_colours, uint8_t *p_buffer )
 {
     if ( !initialised )
         Initialise();
@@ -84,7 +84,7 @@ Image::Image( int p_width, int p_height, int p_colours, JSAMPLE *p_buffer )
     else
     {
         allocation = size;
-        buffer = new JSAMPLE[allocation];
+        buffer = new uint8_t[allocation];
         memset( buffer, 0, size );
     }
     blend_buffer = 0;
@@ -100,7 +100,7 @@ Image::Image( const Image &p_image )
     pixels = p_image.pixels;
     colours = p_image.colours;
     size = allocation = p_image.size;
-    buffer = new JSAMPLE[allocation];
+    buffer = new uint8_t[allocation];
     memcpy( buffer, p_image.buffer, size );
     blend_buffer = 0;
     strncpy( text, p_image.text, sizeof(text) );
@@ -152,13 +152,11 @@ Image::BlendTablePtr Image::GetBlendTable( int transparency )
 		blend_ptr = blend_tables[transparency] = new BlendTable[1];
 		//Info( "Generating blend table for transparency %d", transparency );
 		int opacity = 100-transparency;
-		//int round_up = 50/transparency;
 		for ( int i = 0; i < 256; i++ )
 		{
 			for ( int j = 0; j < 256; j++ )
 			{
-				//(*blend_ptr)[i][j] = (JSAMPLE)((((i + round_up) * opacity)+((j + round_up) * transparency))/100);
-				(*blend_ptr)[i][j] = (JSAMPLE)(((i * opacity)+(j * transparency))/100);
+				(*blend_ptr)[i][j] = (uint8_t)round(((i * opacity)+(j * transparency))/100.0L);
 				//printf( "I:%d, J:%d, B:%d\n", i, j, (*blend_ptr)[i][j] );
 			}
 		}
@@ -190,7 +188,7 @@ void Image::Assign( int p_width, int p_height, int p_colours, unsigned char *new
         {
             allocation = size;
             delete[] buffer;
-            buffer = new JSAMPLE[allocation];
+            buffer = new uint8_t[allocation];
             memset( buffer, 0, size );
         }
     }
@@ -210,7 +208,7 @@ void Image::Assign( const Image &image )
         {
             allocation = size;
             delete[] buffer;
-            buffer = new JSAMPLE[allocation];
+            buffer = new uint8_t[allocation];
             memset( buffer, 0, size );
         }
     }
@@ -221,7 +219,7 @@ Image *Image::HighlightEdges( Rgb colour, const Box *limits )
 {
     if ( colours != 1 )
     {
-        Fatal( "Attempt to highlight image edges when colours = %d", colours );
+        Panic( "Attempt to highlight image edges when colours = %d", colours );
     }
 	Image *high_image = new Image( width, height, 3 );
 	int lo_x = limits?limits->Lo().X():0;
@@ -355,7 +353,7 @@ bool Image::ReadJpeg( const char *filename )
 		{
 			allocation = size;
 			delete[] buffer;
-			buffer = new JSAMPLE[allocation];
+			buffer = new uint8_t[allocation];
 		}
 	}
 
@@ -461,7 +459,7 @@ bool Image::DecodeJpeg( const JOCTET *inbuffer, int inbuffer_size )
 		return( false );
 	}
 
-	jpeg_mem_src( cinfo, inbuffer, inbuffer_size );
+	zm_jpeg_mem_src( cinfo, inbuffer, inbuffer_size );
 
 	jpeg_read_header( cinfo, TRUE );
 
@@ -482,7 +480,7 @@ bool Image::DecodeJpeg( const JOCTET *inbuffer, int inbuffer_size )
 		{
 			allocation = size;
 			delete[] buffer;
-			buffer = new JSAMPLE[allocation];
+			buffer = new uint8_t[allocation];
 		}
 	}
 
@@ -523,7 +521,7 @@ bool Image::EncodeJpeg( JOCTET *outbuffer, int *outbuffer_size, int quality_over
 		jpeg_create_compress( cinfo );
 	}
 
-	jpeg_mem_dest( cinfo, outbuffer, outbuffer_size );
+	zm_jpeg_mem_dest( cinfo, outbuffer, outbuffer_size );
 
 	cinfo->image_width = width; 	/* image width and height, in pixels */
 	cinfo->image_height = height;
@@ -607,7 +605,7 @@ bool Image::Crop( int lo_x, int lo_y, int hi_x, int hi_y )
 	}
 
 	int new_size = new_width*new_height*colours;
-	JSAMPLE *new_buffer = new JSAMPLE[new_size];
+	uint8_t *new_buffer = new uint8_t[new_size];
 
 	int new_stride = new_width*colours;
 	for ( int y = lo_y, ny = 0; y <= hi_y; y++, ny++ )
@@ -644,7 +642,7 @@ void Image::Overlay( const Image &image )
 {
 	if ( !(width == image.width && height == image.height) )
     {
-        Fatal( "Attempt to overlay different sized images, expected %dx%d, got %dx%d", width, height, image.width, image.height );
+        Panic( "Attempt to overlay different sized images, expected %dx%d, got %dx%d", width, height, image.width, image.height );
     }
 
 	unsigned char *pdest = buffer;
@@ -715,17 +713,17 @@ void Image::Overlay( const Image &image, int x, int y )
 {
 	if ( !(width < image.width || height < image.height) )
     {
-        Fatal( "Attempt to overlay image too big for destination, %dx%d > %dx%d", image.width, image.height, width, height );
+        Panic( "Attempt to overlay image too big for destination, %dx%d > %dx%d", image.width, image.height, width, height );
     }
 
 	if ( !(width < (x+image.width) || height < (y+image.height)) )
     {
-        Fatal( "Attempt to overlay image outside of destination bounds, %dx%d @ %dx%d > %dx%d", image.width, image.height, x, y, width, height );
+        Panic( "Attempt to overlay image outside of destination bounds, %dx%d @ %dx%d > %dx%d", image.width, image.height, x, y, width, height );
     }
 
 	if ( !(colours == image.colours) )
     {
-        Fatal( "Attempt to partial overlay differently coloured images, expected %d, got %d", colours, image.colours );
+        Panic( "Attempt to partial overlay differently coloured images, expected %d, got %d", colours, image.colours );
     }
 
 	int lo_x = x;
@@ -764,15 +762,15 @@ void Image::Blend( const Image &image, int transparency ) const
 {
 	if ( !(width == image.width && height == image.height && colours == image.colours) )
     {
-        Fatal( "Attempt to blend different sized images, expected %dx%dx%d, got %dx%dx%d", width, height, colours, image.width, image.height, image.colours );
+        Panic( "Attempt to blend different sized images, expected %dx%dx%d, got %dx%dx%d", width, height, colours, image.width, image.height, image.colours );
     }
 
 	if ( config.fast_image_blends )
 	{
 		BlendTablePtr blend_ptr = GetBlendTable( transparency );
 
-		JSAMPLE *psrc = image.buffer;
-		JSAMPLE *pdest = buffer;
+		uint8_t *psrc = image.buffer;
+		uint8_t *pdest = buffer;
 
 		while( pdest < (buffer+size) )
 		{
@@ -783,26 +781,26 @@ void Image::Blend( const Image &image, int transparency ) const
 	{
 		if ( !blend_buffer )
 		{
-			blend_buffer = new unsigned int[size];
+			blend_buffer = new uint16_t[size];
 
-			unsigned int *pb = blend_buffer;
-			JSAMPLE *p = buffer;
+			uint16_t *pb = blend_buffer;
+			uint8_t *p = buffer;
 			
 			while( p < (buffer+size) )
 			{
-				*pb++ = (unsigned int)((*p++)<<8);
+				*pb++ = (uint16_t)((*p++)<<8);
 			}
 		}
 
-		JSAMPLE *psrc = image.buffer;
-		JSAMPLE *pdest = buffer;
-		unsigned int *pblend = blend_buffer;
+		uint8_t *psrc = image.buffer;
+		uint8_t *pdest = buffer;
+		uint16_t *pblend = blend_buffer;
 		int opacity = 100-transparency;
 
 		while( pdest < (buffer+size) )
 		{
-			*pblend = (unsigned int)(((*pblend * opacity)+(((*psrc++)<<8) * transparency))/100);
-			*pdest++ = (JSAMPLE)((*pblend++)>>8);
+			*pblend = (uint16_t)(((*pblend * opacity)+(((*psrc++)<<8) * transparency))/100);
+			*pdest++ = (uint8_t)((*pblend++)>>8);
 		}
 	}
 }
@@ -819,7 +817,7 @@ Image *Image::Merge( int n_images, Image *images[] )
 	{
 	    if ( !(width == images[i]->width && height == images[i]->height && colours == images[i]->colours) )
         {
-            Fatal( "Attempt to merge different sized images, expected %dx%dx%d, got %dx%dx%d, for image %d", width, height, colours, images[i]->width, images[i]->height, images[i]->colours, i );
+            Panic( "Attempt to merge different sized images, expected %dx%dx%d, got %dx%dx%d, for image %d", width, height, colours, images[i]->width, images[i]->height, images[i]->colours, i );
         }
 	}
 
@@ -828,10 +826,10 @@ Image *Image::Merge( int n_images, Image *images[] )
 	for ( int i = 0; i < size; i++ )
 	{
 		int total = 0;
-		JSAMPLE *pdest = result->buffer;
+		uint8_t *pdest = result->buffer;
 		for ( int j = 0; j < n_images; j++ )
 		{
-			JSAMPLE *psrc = images[j]->buffer;
+			uint8_t *psrc = images[j]->buffer;
 			total += *psrc;
 			psrc++;
 		}
@@ -853,7 +851,7 @@ Image *Image::Merge( int n_images, Image *images[], double weight )
 	{
 	    if ( !(width == images[i]->width && height == images[i]->height && colours == images[i]->colours) )
         {
-            Fatal( "Attempt to merge different sized images, expected %dx%dx%d, got %dx%dx%d, for image %d", width, height, colours, images[i]->width, images[i]->height, images[i]->colours, i );
+            Panic( "Attempt to merge different sized images, expected %dx%dx%d, got %dx%dx%d, for image %d", width, height, colours, images[i]->width, images[i]->height, images[i]->colours, i );
         }
 	}
 
@@ -862,11 +860,11 @@ Image *Image::Merge( int n_images, Image *images[], double weight )
 	double factor = 1.0*weight;
 	for ( int i = 1; i < n_images; i++ )
 	{
-		JSAMPLE *pdest = result->buffer;
-		JSAMPLE *psrc = images[i]->buffer;
+		uint8_t *pdest = result->buffer;
+		uint8_t *psrc = images[i]->buffer;
 		for ( int j = 0; j < size; j++ )
 		{
-			*pdest = (JSAMPLE)(((*pdest)*(1.0-factor))+((*psrc)*factor));
+			*pdest = (uint8_t)(((*pdest)*(1.0-factor))+((*psrc)*factor));
 			pdest++;
 			psrc++;
 		}
@@ -887,7 +885,7 @@ Image *Image::Highlight( int n_images, Image *images[], const Rgb threshold, con
 	{
 	    if ( !(width == images[i]->width && height == images[i]->height && colours == images[i]->colours) )
         {
-            Fatal( "Attempt to highlight different sized images, expected %dx%dx%d, got %dx%dx%d, for image %d", width, height, colours, images[i]->width, images[i]->height, images[i]->colours, i );
+            Panic( "Attempt to highlight different sized images, expected %dx%dx%d, got %dx%dx%d, for image %d", width, height, colours, images[i]->width, images[i]->height, images[i]->colours, i );
         }
 	}
 
@@ -898,10 +896,10 @@ Image *Image::Highlight( int n_images, Image *images[], const Rgb threshold, con
 		for ( int i = 0; i < size; i++ )
 		{
 			int count = 0;
-			JSAMPLE *pdest = result->buffer+c;
+			uint8_t *pdest = result->buffer+c;
 			for ( int j = 0; j < n_images; j++ )
 			{
-				JSAMPLE *psrc = images[j]->buffer+c;
+				uint8_t *psrc = images[j]->buffer+c;
 
 				if ( (unsigned)abs((*psrc)-RGB_VAL(ref_colour,c)) >= RGB_VAL(threshold,c) )
 				{
@@ -920,7 +918,7 @@ Image *Image::Delta( const Image &image ) const
 {
 	if ( !(width == image.width && height == image.height && colours == image.colours) )
     {
-        Fatal( "Attempt to get delta of different sized images, expected %dx%dx%d, got %dx%dx%d", width, height, colours, image.width, image.height, image.colours );
+        Panic( "Attempt to get delta of different sized images, expected %dx%dx%d, got %dx%dx%d", width, height, colours, image.width, image.height, image.colours );
     }
 
 	Image *result = new Image( width, height, 1 );
@@ -965,10 +963,10 @@ Image *Image::Delta( const Image &image ) const
 
 				// This is uses an RMS function, all floating point and 
 				// rather too slow
-				//*pdiff++ = (JSAMPLE)sqrt((red*red + green*green + blue*blue)/3);
+				//*pdiff++ = (uint8_t)sqrt((red*red + green*green + blue*blue)/3);
 
 				// This just uses the average difference, much faster
-				*pdiff++ = (JSAMPLE)((red + green + blue)/3);
+				*pdiff++ = (uint8_t)((red + green + blue)/3);
 			}
 		}
 	}
@@ -1141,10 +1139,10 @@ void Image::Colourise()
 	{
 		colours = 3;
 		size = width * height * 3;
-		JSAMPLE *new_buffer = new JSAMPLE[size];
+		uint8_t *new_buffer = new uint8_t[size];
 
-		JSAMPLE *psrc = buffer;
-		JSAMPLE *pdest = new_buffer;
+		uint8_t *psrc = buffer;
+		uint8_t *pdest = new_buffer;
 		while( pdest < (new_buffer+size) )
 		{
 			RED(pdest) = GREEN(pdest) = BLUE(pdest) = *psrc++;
@@ -1162,11 +1160,11 @@ void Image::DeColourise()
 		colours = 1;
 		size = width * height;
 
-		JSAMPLE *psrc = buffer;
-		JSAMPLE *pdest = buffer;
+		uint8_t *psrc = buffer;
+		uint8_t *pdest = buffer;
 		while( pdest < (buffer+size) )
 		{
-			*pdest++ = (JSAMPLE)sqrt((RED(psrc) + GREEN(psrc) + BLUE(psrc))/3);
+			*pdest++ = (uint8_t)sqrt((RED(psrc) + GREEN(psrc) + BLUE(psrc))/3);
 			psrc += 3;
 		}
 	}
@@ -1176,7 +1174,7 @@ void Image::Fill( Rgb colour, const Box *limits )
 {
 	if ( !(colours == 1 || colours == 3 ) )
     {
-        Fatal( "Attempt to fill image with unexpected colours %d", colours );
+        Panic( "Attempt to fill image with unexpected colours %d", colours );
     }
 	int lo_x = limits?limits->Lo().X():0;
 	int lo_y = limits?limits->Lo().Y():0;
@@ -1213,7 +1211,7 @@ void Image::Fill( Rgb colour, int density, const Box *limits )
 {
 	if ( !(colours == 1 || colours == 3 ) )
     {
-        Fatal( "Attempt to fill image with unexpected colours %d", colours );
+        Panic( "Attempt to fill image with unexpected colours %d", colours );
     }
 
 	int lo_x = limits?limits->Lo().X():0;
@@ -1246,7 +1244,7 @@ void Image::Outline( Rgb colour, const Polygon &polygon )
 {
 	if ( !(colours == 1 || colours == 3 ) )
     {
-        Fatal( "Attempt to outline image with unexpected colours %d", colours );
+        Panic( "Attempt to outline image with unexpected colours %d", colours );
     }
 	int n_coords = polygon.getNumCoords();
 	for ( int j = 0, i = n_coords-1; j < n_coords; i = j++ )
@@ -1335,7 +1333,7 @@ void Image::Fill( Rgb colour, int density, const Polygon &polygon )
 {
 	if ( !(colours == 1 || colours == 3 ) )
     {
-        Fatal( "Attempt to fill image with unexpected colours %d", colours );
+        Panic( "Attempt to fill image with unexpected colours %d", colours );
     }
 
 	int n_coords = polygon.getNumCoords();
@@ -1367,7 +1365,7 @@ void Image::Fill( Rgb colour, int density, const Polygon &polygon )
 	qsort( global_edges, n_global_edges, sizeof(*global_edges), Edge::CompareYX );
 
 #ifndef ZM_DBG_OFF
-	if ( zm_dbg_level >= 9 )
+	if ( zmDbgLevel >= 9 )
 	{
 		for ( int i = 0; i < n_global_edges; i++ )
 		{
@@ -1402,7 +1400,7 @@ void Image::Fill( Rgb colour, int density, const Polygon &polygon )
 		}
 		qsort( active_edges, n_active_edges, sizeof(*active_edges), Edge::CompareX );
 #ifndef ZM_DBG_OFF
-		if ( zm_dbg_level >= 9 )
+		if ( zmDbgLevel >= 9 )
 		{
 			for ( int i = 0; i < n_active_edges; i++ )
 			{
