@@ -1,5 +1,5 @@
 /*
- * ZoneMinder Jpeg Interface, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+ * ZoneMinder Jpeg Interface, $Date: 2010-01-20 14:43:54 +0000 (Wed, 20 Jan 2010) $, $Revision: 3012 $
  * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
@@ -36,5 +36,5 @@ void zm_jpeg_error_exit( j_common_ptr cinfo );
 void zm_jpeg_emit_message( j_common_ptr cinfo, int msg_level );
 
 // Prototypes for memory compress/decompression object */
-void jpeg_mem_src(j_decompress_ptr cinfo, const JOCTET *inbuffer, int inbuffer_size );
-void jpeg_mem_dest(j_compress_ptr cinfo, JOCTET *outbuffer, int *outbuffer_size );
+void zm_jpeg_mem_src(j_decompress_ptr cinfo, const JOCTET *inbuffer, int inbuffer_size );
+void zm_jpeg_mem_dest(j_compress_ptr cinfo, JOCTET *outbuffer, int *outbuffer_size );
