@@ -1,5 +1,5 @@
 //
-// ZoneMinder Local Camera Class Implementation, $Date: 2009-05-13 11:43:49 +0100 (Wed, 13 May 2009) $, $Revision: 2870 $
+// ZoneMinder Local Camera Class Implementation, $Date: 2011-02-17 09:31:33 +0000 (Thu, 17 Feb 2011) $, $Revision: 3304 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -17,6 +17,10 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // 
 
+#include "zm.h"
+
+#if ZM_HAS_V4L
+
 #include "zm_local_camera.h"
 
 #include <sys/types.h>
@@ -40,7 +44,7 @@ static int vidioctl( int fd, int request, void *arg )
 static PixelFormat getFfPixFormatFromV4lPalette( int v4l_version, int palette )
 {
     PixelFormat pixFormat = PIX_FMT_NONE;
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
     if ( v4l_version == 2 )
     {
         switch( palette )
@@ -165,8 +169,8 @@ static PixelFormat getFfPixFormatFromV4lPalette( int v4l_version, int palette )
             }
         }
     }
-    else
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
     if ( v4l_version == 1 )
     {
         switch( palette )
@@ -231,6 +235,7 @@ static PixelFormat getFfPixFormatFromV4lPalette( int v4l_version, int palette )
             }
         }
     }
+#endif // ZM_HAS_V4L1
     return( pixFormat );
 }
 #endif // HAVE_LIBSWSCALE
@@ -243,10 +248,12 @@ int LocalCamera::standards[VIDEO_MAX_FRAME];
 int LocalCamera::vid_fd = -1;
 
 int LocalCamera::v4l_version = 0;
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
 LocalCamera::V4L2Data LocalCamera::v4l2_data;
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
 LocalCamera::V4L1Data LocalCamera::v4l1_data;
+#endif // ZM_HAS_V4L1
 
 #if HAVE_LIBSWSCALE
 AVFrame **LocalCamera::capturePictures = 0;
@@ -262,11 +269,11 @@ short *LocalCamera::b_u_table;
 LocalCamera *LocalCamera::last_camera = NULL;
 
 LocalCamera::LocalCamera( int p_id, const std::string &p_device, int p_channel, int p_standard, const std::string &p_method, int p_width, int p_height, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture ) :
-#ifdef ZM_V4L2
-    Camera( p_id, LOCAL_SRC, p_width, p_height, ((p_palette==VIDEO_PALETTE_GREY||p_palette==V4L2_PIX_FMT_GREY)?1:3), p_brightness, p_contrast, p_hue, p_colour, p_capture ),
-#else // ZM_V4L2
+#if ZM_HAS_V4L2
+    Camera( p_id, LOCAL_SRC, p_width, p_height, (p_palette==V4L2_PIX_FMT_GREY?1:3), p_brightness, p_contrast, p_hue, p_colour, p_capture ),
+#elif ZM_HAS_V4L1
     Camera( p_id, LOCAL_SRC, p_width, p_height, (p_palette==VIDEO_PALETTE_GREY?1:3), p_brightness, p_contrast, p_hue, p_colour, p_capture ),
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
     device( p_device ),
     channel( p_channel ),
     standard( p_standard ),
@@ -282,9 +289,7 @@ LocalCamera::LocalCamera( int p_id, const std::string &p_device, int p_channel,
 	    if ( device_prime )
         {
             v4l_version = (p_method=="v4l2"?2:1);
-#ifdef ZM_V4L2
-            Debug( 2, "V4L2 support enabled, using V4L%d api", v4l_version );
-#endif // ZM_V4L2
+            Debug( 2, "V4L support enabled, using V4L%d api", v4l_version );
         }
 
         if ( !last_camera || channel != last_camera->channel )
@@ -332,7 +337,7 @@ LocalCamera::~LocalCamera()
 void LocalCamera::Initialise()
 {
 #if HAVE_LIBSWSCALE
-    if ( zm_dbg_level > ZM_DBG_INF )
+    if ( zmDbgLevel > ZM_DBG_INF )
         av_log_set_level( AV_LOG_DEBUG );
     else
         av_log_set_level( AV_LOG_QUIET );
@@ -351,7 +356,7 @@ void LocalCamera::Initialise()
     if ( (vid_fd = open( device.c_str(), O_RDWR, 0 )) < 0 )
 		Fatal( "Failed to open video device %s: %s", device.c_str(), strerror(errno) );
 
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
     Debug( 2, "V4L2 support enabled, using V4L%d api", v4l_version );
     if ( v4l_version == 2 )
     {
@@ -375,17 +380,45 @@ void LocalCamera::Initialise()
         if ( vidioctl( vid_fd, VIDIOC_G_FMT, &v4l2_data.fmt ) < 0 )
             Fatal( "Failed to get video format: %s", strerror(errno) );
 
+        Debug( 4, " v4l2_data.fmt.type = %08x",  v4l2_data.fmt.type );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.width = %08x",  v4l2_data.fmt.fmt.pix.width );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.height = %08x",  v4l2_data.fmt.fmt.pix.height );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.pixelformat = %08x",  v4l2_data.fmt.fmt.pix.pixelformat );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.field = %08x",  v4l2_data.fmt.fmt.pix.field );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.bytesperline = %08x",  v4l2_data.fmt.fmt.pix.bytesperline );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.sizeimage = %08x",  v4l2_data.fmt.fmt.pix.sizeimage );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.colorspace = %08x",  v4l2_data.fmt.fmt.pix.colorspace );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.priv = %08x",  v4l2_data.fmt.fmt.pix.priv );
+
         v4l2_data.fmt.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
         v4l2_data.fmt.fmt.pix.width = width; 
         v4l2_data.fmt.fmt.pix.height = height;
         v4l2_data.fmt.fmt.pix.pixelformat = palette;
-        //v4l2_data.fmt.fmt.pix.field = V4L2_FIELD_INTERLACED;
-        v4l2_data.fmt.fmt.pix.field = V4L2_FIELD_ANY;
 
+        if ( config.v4l2_capture_fields )
+        {
+            v4l2_data.fmt.fmt.pix.field = (v4l2_field)config.v4l2_capture_fields;
+            if ( vidioctl( vid_fd, VIDIOC_S_FMT, &v4l2_data.fmt ) < 0 )
+            {
+                Warning( "Failed to set V4L2 field to %d, falling back to auto", config.v4l2_capture_fields );
+                v4l2_data.fmt.fmt.pix.field = V4L2_FIELD_ANY;
+                if ( vidioctl( vid_fd, VIDIOC_S_FMT, &v4l2_data.fmt ) < 0 )
+                    Fatal( "Failed to set video format: %s", strerror(errno) );
+            }
+        }
         if ( vidioctl( vid_fd, VIDIOC_S_FMT, &v4l2_data.fmt ) < 0 )
             Fatal( "Failed to set video format: %s", strerror(errno) );
 
         /* Note VIDIOC_S_FMT may change width and height. */
+        Debug( 4, " v4l2_data.fmt.type = %08x",  v4l2_data.fmt.type );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.width = %08x",  v4l2_data.fmt.fmt.pix.width );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.height = %08x",  v4l2_data.fmt.fmt.pix.height );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.pixelformat = %08x",  v4l2_data.fmt.fmt.pix.pixelformat );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.field = %08x",  v4l2_data.fmt.fmt.pix.field );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.bytesperline = %08x",  v4l2_data.fmt.fmt.pix.bytesperline );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.sizeimage = %08x",  v4l2_data.fmt.fmt.pix.sizeimage );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.colorspace = %08x",  v4l2_data.fmt.fmt.pix.colorspace );
+        Debug( 4, " v4l2_data.fmt.fmt.pix.priv = %08x",  v4l2_data.fmt.fmt.pix.priv );
 
         /* Buggy driver paranoia. */
         unsigned int min;
@@ -452,12 +485,12 @@ void LocalCamera::Initialise()
                 Fatal( "Can't map video buffer %d (%d bytes) to memory: %s(%d)", i, vid_buf.length, strerror(errno), errno );
 
 #if HAVE_LIBSWSCALE
-            if ( imagePixFormat != capturePixFormat )
+            if ( imagePixFormat != capturePixFormat || v4l2_data.fmt.fmt.pix.width != width || v4l2_data.fmt.fmt.pix.height != height )
             {
                 capturePictures[i] = avcodec_alloc_frame();
                 if ( !capturePictures[i] )
                     Fatal( "Could not allocate picture" );
-                avpicture_fill( (AVPicture *)capturePictures[i], (unsigned char *)v4l2_data.buffers[i].start, capturePixFormat, width, height );
+                avpicture_fill( (AVPicture *)capturePictures[i], (unsigned char *)v4l2_data.buffers[i].start, capturePixFormat, v4l2_data.fmt.fmt.pix.width, v4l2_data.fmt.fmt.pix.height );
             }
 #endif // HAVE_LIBSWSCALE
         }
@@ -495,8 +528,8 @@ void LocalCamera::Initialise()
         Hue(hue);
         Colour(colour);
     }
-    else
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
     if ( v4l_version == 1 )
     {
         Debug( 3, "Configuring picture attributes" );
@@ -575,6 +608,10 @@ void LocalCamera::Initialise()
                 exit(-1);
         }
 
+        Info( "vid_win.width = %08x", vid_win.width );
+        Info( "vid_win.height = %08x", vid_win.height );
+        Info( "vid_win.flags = %08x", vid_win.flags );
+
         Debug( 3, "Setting up request buffers" );
         if ( ioctl( vid_fd, VIDIOCGMBUF, &v4l1_data.frames ) < 0 )
             Fatal( "Failed to setup memory: %s", strerror(errno) );
@@ -635,6 +672,10 @@ void LocalCamera::Initialise()
         if ( ioctl( vid_fd, VIDIOCGWIN, &vid_win) < 0 )
             Fatal( "Failed to get window data: %s", strerror(errno) );
 
+        Info( "vid_win.width = %08x", vid_win.width );
+        Info( "vid_win.height = %08x", vid_win.height );
+        Info( "vid_win.flags = %08x", vid_win.flags );
+
         Debug( 4, "New X:%d", vid_win.x );
         Debug( 4, "New Y:%d", vid_win.y );
         Debug( 4, "New W:%d", vid_win.width );
@@ -650,6 +691,7 @@ void LocalCamera::Initialise()
         Debug( 4, "New Cl:%d", vid_pic.colour );
         Debug( 4, "New Cn:%d", vid_pic.contrast );
     }
+#endif // ZM_HAS_V4L1
 
     Debug( 3, "Setting up static colour tables" );
 
@@ -692,7 +734,7 @@ void LocalCamera::Initialise()
 
 void LocalCamera::Terminate()
 {
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
     if ( v4l_version == 2 )
     {
         Debug( 3, "Terminating video stream" );
@@ -707,7 +749,8 @@ void LocalCamera::Terminate()
                 Error( "Failed to munmap buffer %d: %s", i, strerror(errno) );
     }
     else
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
     if ( v4l_version == 1 )
     {
         Debug( 3, "Unmapping video buffers" );
@@ -716,6 +759,7 @@ void LocalCamera::Terminate()
 
 	    delete[] v4l1_data.buffers;
     }
+#endif // ZM_HAS_V4L1
 
 	close( vid_fd );
 }
@@ -756,7 +800,7 @@ bool LocalCamera::GetCurrentSettings( const char *device, char *output, int vers
         else
             sprintf( output+strlen(output), "d:%s|", queryDevice );
 
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
         if ( version == 2 )
         {
             struct v4l2_capability vid_cap;
@@ -841,7 +885,7 @@ bool LocalCamera::GetCurrentSettings( const char *device, char *output, int vers
                     sprintf( output+strlen(output), "%s/", standard.name );
             }
             while ( standardIndex++ >= 0 );
-            if ( !verbose )
+            if ( !verbose && output[strlen(output)-1] == '/')
                 output[strlen(output)-1] = '|';
       
             if ( verbose )
@@ -910,15 +954,26 @@ bool LocalCamera::GetCurrentSettings( const char *device, char *output, int vers
             crop.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
             if ( vidioctl( vid_fd, VIDIOC_G_CROP, &crop ) < 0 )
             {
-                Error( "Failed to query crop: %s", strerror(errno) );
-                if ( verbose )
-                    sprintf( output, "Error, failed to query crop %s: %s\n", queryDevice, strerror(errno) );
-                else
-                    sprintf( output, "error%d\n", errno );
-                return( false );
+                if ( errno != EINVAL )
+                {
+                    Error( "Failed to query crop: %s", strerror(errno) );
+                    if ( verbose )
+                        sprintf( output, "Error, failed to query crop %s: %s\n", queryDevice, strerror(errno) );
+                    else
+                        sprintf( output, "error%d\n", errno );
+
+                    return( false );
+                }
+                else if ( verbose )
+                {
+                    Info( "Does not support VIDIOC_G_CROP");
+                }
             }
-            if ( verbose )
+            else
+            {
+                if ( verbose )
                 sprintf( output+strlen(output), "  Current: %d x %d\n", crop.c.width, crop.c.height );
+            }
 
             struct v4l2_input input;
             int inputIndex = 0;
@@ -1019,8 +1074,9 @@ bool LocalCamera::GetCurrentSettings( const char *device, char *output, int vers
             if ( !verbose )
                 output[strlen(output)-1] = '\n';
         }
-        else
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
+        if ( version == 1 )
         {
             struct video_capability vid_cap;
             if ( ioctl( vid_fd, VIDIOCGCAP, &vid_cap ) < 0 )
@@ -1193,6 +1249,7 @@ bool LocalCamera::GetCurrentSettings( const char *device, char *output, int vers
             if ( !verbose )
                 output[strlen(output)-1] = '\n';
         }
+#endif // ZM_HAS_V4L1
         close( vid_fd );
         if ( device )
             break;
@@ -1203,7 +1260,7 @@ bool LocalCamera::GetCurrentSettings( const char *device, char *output, int vers
 
 int LocalCamera::Brightness( int p_brightness )
 {
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
     if ( v4l_version == 2 )
     {
         struct v4l2_control vid_control;
@@ -1217,13 +1274,13 @@ int LocalCamera::Brightness( int p_brightness )
                 Error( "Unable to query brightness: %s", strerror(errno) )
             else
                 Warning( "Brightness control is not suppported" )
-            Info( "Brightness 1 %d", vid_control.value );
+            //Info( "Brightness 1 %d", vid_control.value );
         }
         else if ( p_brightness >= 0 )
         {
             vid_control.value = p_brightness;
 
-            Info( "Brightness 2 %d", vid_control.value );
+            //Info( "Brightness 2 %d", vid_control.value );
             /* The driver may clamp the value or return ERANGE, ignored here */
             if ( vidioctl ( vid_fd, VIDIOC_S_CTRL, &vid_control ) )
             {
@@ -1232,12 +1289,12 @@ int LocalCamera::Brightness( int p_brightness )
                 else
                     Warning( "Given brightness value (%d) may be out-of-range", p_brightness )
             }
-            Info( "Brightness 3 %d", vid_control.value );
+            //Info( "Brightness 3 %d", vid_control.value );
         }
         return( vid_control.value );
     }
-    else
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
     if ( v4l_version == 1 )
     {
         struct video_picture vid_pic;
@@ -1258,12 +1315,13 @@ int LocalCamera::Brightness( int p_brightness )
         }
         return( vid_pic.brightness );
     }
+#endif // ZM_HAS_V4L1
     return( -1 );
 }
 
 int LocalCamera::Hue( int p_hue )
 {
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
     if ( v4l_version == 2 )
     {
         struct v4l2_control vid_control;
@@ -1293,8 +1351,8 @@ int LocalCamera::Hue( int p_hue )
         }
         return( vid_control.value );
     }
-    else
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
     if ( v4l_version == 1 )
     {
         struct video_picture vid_pic;
@@ -1315,12 +1373,13 @@ int LocalCamera::Hue( int p_hue )
         }
         return( vid_pic.hue );
     }
+#endif // ZM_HAS_V4L1
     return( -1 );
 }
 
 int LocalCamera::Colour( int p_colour )
 {
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
     if ( v4l_version == 2 )
     {
         struct v4l2_control vid_control;
@@ -1350,8 +1409,8 @@ int LocalCamera::Colour( int p_colour )
         }
         return( vid_control.value );
     }
-    else
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
     if ( v4l_version == 1 )
     {
         struct video_picture vid_pic;
@@ -1372,12 +1431,13 @@ int LocalCamera::Colour( int p_colour )
         }
         return( vid_pic.colour );
     }
+#endif // ZM_HAS_V4L1
     return( -1 );
 }
 
 int LocalCamera::Contrast( int p_contrast )
 {
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
     if ( v4l_version == 2 )
     {
         struct v4l2_control vid_control;
@@ -1407,8 +1467,8 @@ int LocalCamera::Contrast( int p_contrast )
         }
         return( vid_control.value );
     }
-    else
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
     if ( v4l_version == 1 )
     {
         struct video_picture vid_pic;
@@ -1429,6 +1489,7 @@ int LocalCamera::Contrast( int p_contrast )
         }
         return( vid_pic.contrast );
     }
+#endif // ZM_HAS_V4L1
     return( -1 );
 }
 
@@ -1437,7 +1498,7 @@ int LocalCamera::PrimeCapture()
     Initialise();
 
     Debug( 2, "Priming capture" );
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
     if ( v4l_version == 2 )
     {
         Debug( 3, "Queueing buffers" );
@@ -1462,8 +1523,8 @@ int LocalCamera::PrimeCapture()
         if ( vidioctl( vid_fd, VIDIOC_STREAMON, &type ) < 0 )
             Fatal( "Failed to start capture stream: %s", strerror(errno) );
     }
-    else
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
     if ( v4l_version == 1 )
     {
         for ( int frame = 0; frame < v4l1_data.frames.frames; frame++ )
@@ -1476,6 +1537,7 @@ int LocalCamera::PrimeCapture()
             }
         }
     }
+#endif // ZM_HAS_V4L1
 
     return( 0 );
 }
@@ -1495,12 +1557,14 @@ int LocalCamera::Capture( Image &image )
 	int captures_per_frame = 1;
 	if ( channel_count > 1 )
 		captures_per_frame = config.captures_per_frame;
+    int captureWidth = width;
+    int captureHeight = height;
 
     // Do the capture, unless we are the second or subsequent camera on a channel, in which case just reuse the buffer
     if ( channel_prime )
     {
         int capture_frame = -1;
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
         if ( v4l_version == 2 )
         {
             static struct v4l2_buffer vid_buf;
@@ -1538,9 +1602,12 @@ int LocalCamera::Capture( Image &image )
             Debug( 3, "Captured frame %d/%d from channel %d", capture_frame, v4l2_data.bufptr->sequence, channel );
 
             buffer = (unsigned char *)v4l2_data.buffers[v4l2_data.bufptr->index].start;
+
+            captureWidth = v4l2_data.fmt.fmt.pix.width;
+            captureHeight = v4l2_data.fmt.fmt.pix.height;
         }
-        else
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
         if ( v4l_version == 1 )
         {
             Debug( 3, "Capturing %d frames", captures_per_frame );
@@ -1568,18 +1635,18 @@ int LocalCamera::Capture( Image &image )
 
             buffer = v4l1_data.bufptr+v4l1_data.frames.offsets[capture_frame];
         }
-
+#endif // ZM_HAS_V4L1
+#if HAVE_LIBSWSCALE
         Debug( 3, "Doing format conversion" );
 
-#if HAVE_LIBSWSCALE
         static struct SwsContext *imgConversionContext = 0;
         static AVFrame *tmpPicture = NULL;
 
-        if ( imagePixFormat != capturePixFormat )
+        if ( imagePixFormat != capturePixFormat || captureWidth != width || captureHeight != height )
         {
             if ( !imgConversionContext )
             {
-                imgConversionContext = sws_getContext( width, height, capturePixFormat, width, height, imagePixFormat, SWS_BICUBIC, NULL, NULL, NULL );
+                imgConversionContext = sws_getCachedContext( NULL, captureWidth, captureHeight, capturePixFormat, width, height, imagePixFormat, SWS_BICUBIC, NULL, NULL, NULL );
                 if ( !imgConversionContext )
                     Fatal( "Unable to initialise image scaling context" );
 
@@ -1599,10 +1666,12 @@ int LocalCamera::Capture( Image &image )
         static unsigned char temp_buffer[ZM_MAX_IMAGE_SIZE];
         switch( palette )
         {
+#if ZM_HAS_V4L1
             case VIDEO_PALETTE_YUV420P :
-#ifdef ZM_V4L2
+#endif // ZM_HAS_V4L1
+#if ZM_HAS_V4L2
             case V4L2_PIX_FMT_YUV420 :
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
             {
                 static unsigned char y_plane[ZM_MAX_IMAGE_DIM];
                 static char u_plane[ZM_MAX_IMAGE_DIM];
@@ -1674,10 +1743,12 @@ int LocalCamera::Capture( Image &image )
                 buffer = temp_buffer;
                 break;
             }
+#if ZM_HAS_V4L1
             case VIDEO_PALETTE_YUV422P :
-#ifdef ZM_V4L2
+#endif // ZM_HAS_V4L1
+#if ZM_HAS_V4L2
             case V4L2_PIX_FMT_YUV422P :
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
             {
                 static unsigned char y_plane[ZM_MAX_IMAGE_DIM];
                 static char u_plane[ZM_MAX_IMAGE_DIM];
@@ -1734,11 +1805,13 @@ int LocalCamera::Capture( Image &image )
                 buffer = temp_buffer;
                 break;
             }
+#if ZM_HAS_V4L1
             case VIDEO_PALETTE_YUYV :
             case VIDEO_PALETTE_YUV422 :
-#ifdef ZM_V4L2
+#endif // ZM_HAS_V4L1
+#if ZM_HAS_V4L2
             case V4L2_PIX_FMT_YUYV :
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
             {
                 int size = width*height*2;
                 unsigned char *s_ptr = buffer;
@@ -1772,10 +1845,12 @@ int LocalCamera::Capture( Image &image )
                 buffer = temp_buffer;
                 break;
             }
+#if ZM_HAS_V4L1
             case VIDEO_PALETTE_RGB555 :
-#ifdef ZM_V4L2
+#endif // ZM_HAS_V4L1
+#if ZM_HAS_V4L2
             case V4L2_PIX_FMT_RGB555 :
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
             {
                 int size = width*height*2;
                 unsigned char r,g,b;
@@ -1795,10 +1870,12 @@ int LocalCamera::Capture( Image &image )
                 buffer = temp_buffer;
                 break;
             }
+#if ZM_HAS_V4L1
             case VIDEO_PALETTE_RGB565 :
-#ifdef ZM_V4L2
+#endif // ZM_HAS_V4L1
+#if ZM_HAS_V4L2
             case V4L2_PIX_FMT_RGB565 :
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
             {
                 int size = width*height*2;
                 unsigned char r,g,b;
@@ -1818,6 +1895,7 @@ int LocalCamera::Capture( Image &image )
                 buffer = temp_buffer;
                 break;
             }
+#if ZM_HAS_V4L1
             case VIDEO_PALETTE_RGB24 :
             {
                 if ( config.local_bgr_invert )
@@ -1836,7 +1914,8 @@ int LocalCamera::Capture( Image &image )
                 }
                 break;
             }
-#ifdef ZM_V4L2
+#endif // ZM_HAS_V4L1
+#if ZM_HAS_V4L2
             case V4L2_PIX_FMT_BGR24 :
             {
                 int size = width*height*3;
@@ -1852,11 +1931,13 @@ int LocalCamera::Capture( Image &image )
                 buffer = temp_buffer;
                 break;
             }
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
             case VIDEO_PALETTE_GREY :
-#ifdef ZM_V4L2
+#endif // ZM_HAS_V4L1
+#if ZM_HAS_V4L2
             case V4L2_PIX_FMT_GREY :
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
             {
                 //int size = width*height;
                 //for ( int i = 0; i < size; i++ )
@@ -1887,7 +1968,7 @@ int LocalCamera::PostCapture()
     // Requeue the buffer unless we need to switch or are a duplicate camera on a channel
     if ( channel_count == 1 || channel_prime )
     {
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L2
         if ( v4l_version == 2 )
         {
             if ( channel_count > 1 )
@@ -1914,8 +1995,8 @@ int LocalCamera::PostCapture()
                 return( -1 );
             }
         }
-        else
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2
+#if ZM_HAS_V4L1
         if ( v4l_version == 1 )
         {
             if ( channel_count > 1 )
@@ -1949,7 +2030,9 @@ int LocalCamera::PostCapture()
             }
             v4l1_data.active_frame = (v4l1_data.active_frame+1)%v4l1_data.frames.frames;
         }
+#endif // ZM_HAS_V4L1
     }
 	return( 0 );
 }
 
+#endif // ZM_HAS_V4L
