@@ -1,5 +1,5 @@
 //
-// ZoneMinder Remote Camera Class Implementation, $Date: 2009-05-28 09:47:59 +0100 (Thu, 28 May 2009) $, $Revision: 2905 $
+// ZoneMinder Remote Camera Class Implementation, $Date: 2010-11-11 12:22:35 +0000 (Thu, 11 Nov 2010) $, $Revision: 3189 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -62,7 +62,8 @@ void RemoteCameraHttp::Initialise()
 		request = stringtf( "GET %s HTTP/%s\r\n", path.c_str(), config.http_version );
 		request += stringtf( "User-Agent: %s/%s\r\n", config.http_ua, ZM_VERSION );
 		request += stringtf( "Host: %s\r\n", host .c_str());
-		request += stringtf( "Connection: Keep-Alive\r\n" );
+        if ( strcmp( config.http_version, "1.0" ) == 0 )
+		    request += stringtf( "Connection: Keep-Alive\r\n" );
 		if ( !auth.empty() )
 			request += stringtf( "Authorization: Basic %s\r\n", auth64.c_str() );
 		request += "\r\n";
@@ -110,6 +111,7 @@ int RemoteCameraHttp::Disconnect()
 {
 	close( sd );
 	sd = -1;
+    Debug( 3, "Disconnected from host" );
 	return( 0 );
 }
 
@@ -138,8 +140,9 @@ int RemoteCameraHttp::ReadData( Buffer &buffer, int bytes_expected )
 	int n_found = select( sd+1, &rfds, NULL, NULL, &temp_timeout );
 	if( n_found == 0 )
 	{
-		Error( "Select timed out" );
-		return( -1 );
+		Warning( "Select timed out" );
+		Disconnect();
+		return( 0 );
 	}
 	else if ( n_found < 0)
 	{
@@ -173,7 +176,7 @@ int RemoteCameraHttp::ReadData( Buffer &buffer, int bytes_expected )
 	int total_bytes_read = 0;
 	do
 	{
-		static unsigned char temp_buffer[5*BUFSIZ];
+		static unsigned char temp_buffer[ZM_NETWORK_BUFSIZ];
 		int bytes_to_read = total_bytes_to_read>sizeof(temp_buffer)?sizeof(temp_buffer):total_bytes_to_read;
 		int bytes_read = read( sd, temp_buffer, bytes_to_read );
 
@@ -235,7 +238,12 @@ int RemoteCameraHttp::GetResponse()
 					static RegExpr *content_type_expr = 0;
 
 					int buffer_len = ReadData( buffer );
-					if ( buffer_len < 0 )
+					if ( buffer_len == 0 )
+                    {
+                        Error( "Connection dropped by remote end" );
+                        return( 0 );
+                    }
+					else if ( buffer_len < 0 )
 					{
                         Error( "Unable to read header data" );
 						return( -1 );
@@ -386,7 +394,12 @@ int RemoteCameraHttp::GetResponse()
 					{
 						Debug( 3, "Unable to extract subheader from stream, retrying" );
 						int buffer_len = ReadData( buffer );
-						if ( buffer_len < 0 )
+					    if ( buffer_len == 0 )
+                        {
+                            Error( "Connection dropped by remote end" );
+                            return( 0 );
+                        }
+					    else if ( buffer_len < 0 )
 						{
 							return( -1 );
 						}
@@ -418,7 +431,12 @@ int RemoteCameraHttp::GetResponse()
 						while ( buffer.size() < content_length )
 						{
 							int buffer_len = ReadData( buffer );
-							if ( buffer_len < 0 )
+					        if ( buffer_len == 0 )
+                            {
+                                Error( "Connection dropped by remote end" );
+                                return( 0 );
+                            }
+					        else if ( buffer_len < 0 )
 							{
                                 Error( "Unable to read content" );
 								return( -1 );
@@ -431,7 +449,12 @@ int RemoteCameraHttp::GetResponse()
 						while ( !content_length )
 						{
 							int buffer_len = ReadData( buffer );
-							if ( buffer_len < 0 )
+					        if ( buffer_len == 0 )
+                            {
+                                Error( "Connection dropped by remote end" );
+                                return( 0 );
+                            }
+					        else if ( buffer_len < 0 )
 							{
                                 Error( "Unable to read content" );
 								return( -1 );
@@ -572,7 +595,12 @@ int RemoteCameraHttp::GetResponse()
 				case HEADERCONT :
 				{
 					int buffer_len = ReadData( buffer );
-					if ( buffer_len < 0 )
+                    if ( buffer_len == 0 )
+                    {
+                        Error( "Connection dropped by remote end" );
+                        return( 0 );
+                    }
+                    else if ( buffer_len < 0 )
 					{
                         Error( "Unable to read header" );
 						return( -1 );
@@ -884,7 +912,12 @@ int RemoteCameraHttp::GetResponse()
 					{
 						Debug( 3, "Unable to extract subheader from stream, retrying" );
 						int buffer_len = ReadData( buffer );
-						if ( buffer_len < 0 )
+                        if ( buffer_len == 0 )
+                        {
+                            Error( "Connection dropped by remote end" );
+                            return( 0 );
+                        }
+                        else if ( buffer_len < 0 )
 						{
                             Error( "Unable to read subheader" );
 							return( -1 );
@@ -928,7 +961,12 @@ int RemoteCameraHttp::GetResponse()
 						{
 							//int buffer_len = ReadData( buffer, content_length-buffer.size() );
 							int buffer_len = ReadData( buffer );
-							if ( buffer_len < 0 )
+                            if ( buffer_len == 0 )
+                            {
+                                Error( "Connection dropped by remote end" );
+                                return( 0 );
+                            }
+                            else if ( buffer_len < 0 )
 							{
                                 Error( "Unable to read content" );
 								return( -1 );
@@ -942,12 +980,17 @@ int RemoteCameraHttp::GetResponse()
 						while ( !content_length )
 						{
 							int buffer_len = ReadData( buffer );
-							int buffer_size = buffer.size();
-							if ( buffer_len < 0 )
+                            if ( buffer_len == 0 )
+                            {
+                                Error( "Connection dropped by remote end" );
+                                return( 0 );
+                            }
+                            else if ( buffer_len < 0 )
 							{
                                 Error( "Unable to read content" );
 								return( -1 );
 							}
+							int buffer_size = buffer.size();
 							if ( buffer_len )
 							{
 								if ( mode == MULTI_IMAGE )
@@ -1038,6 +1081,11 @@ int RemoteCameraHttp::PreCapture()
 int RemoteCameraHttp::Capture( Image &image )
 {
 	int content_length = GetResponse();
+    if ( content_length == 0 )
+    {
+        Warning( "Unable to capture image, retrying" );
+        return( 1 );
+    }
 	if ( content_length < 0 )
 	{
         Error( "Unable to get response" );
