@@ -1,5 +1,5 @@
 //
-// ZoneMinder Remote Camera Class Implementation, $Date: 2009-06-03 09:10:28 +0100 (Wed, 03 Jun 2009) $, $Revision: 2907 $
+// ZoneMinder Remote Camera Class Implementation, $Date: 2011-05-15 21:38:51 +0100 (Sun, 15 May 2011) $, $Revision: 3338 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -65,7 +65,7 @@ void RemoteCameraRtsp::Initialise()
 
 	buffer.size( max_size );
 
-    if ( zm_dbg_level > ZM_DBG_INF )
+    if ( zmDbgLevel > ZM_DBG_INF )
         av_log_set_level( AV_LOG_DEBUG ); 
     else
         av_log_set_level( AV_LOG_QUIET ); 
@@ -124,7 +124,11 @@ int RemoteCameraRtsp::PrimeCapture()
     // Find the first video stream
     int videoStream=-1;
     for ( int i = 0; i < formatContext->nb_streams; i++ )
-        if ( formatContext->streams[i]->codec->codec_type == CODEC_TYPE_VIDEO )
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(51,2,1)
+	if ( formatContext->streams[i]->codec->codec_type == AVMEDIA_TYPE_VIDEO )
+#else
+	if ( formatContext->streams[i]->codec->codec_type == CODEC_TYPE_VIDEO )
+#endif
         {
             videoStream = i;
             break;
@@ -138,11 +142,11 @@ int RemoteCameraRtsp::PrimeCapture()
     // Find the decoder for the video stream
     codec = avcodec_find_decoder( codecContext->codec_id );
     if ( codec == NULL )
-        Fatal( "Unable to locate codec %d decoder", codecContext->codec_id );
+        Panic( "Unable to locate codec %d decoder", codecContext->codec_id );
 
     // Open codec
     if ( avcodec_open( codecContext, codec ) < 0 )
-        Fatal( "Can't open codec" );
+        Panic( "Can't open codec" );
 
     picture = avcodec_alloc_frame();
 
@@ -185,14 +189,14 @@ int RemoteCameraRtsp::Capture( Image &image )
                     tmp_picture = avcodec_alloc_frame();
                     if ( !tmp_picture )
                     {
-                        Fatal( "Could not allocate temporary opicture" );
+                        Panic( "Could not allocate temporary opicture" );
                     }
                     int size = avpicture_get_size( PIX_FMT_RGB24, width, height);
                     uint8_t *tmp_picture_buf = (uint8_t *)malloc(size);
                     if (!tmp_picture_buf)
                     {
                         av_free( tmp_picture );
-                        Fatal( "Could not allocate temporary opicture" );
+                        Panic( "Could not allocate temporary opicture" );
                     }
                     avpicture_fill( (AVPicture *)tmp_picture, tmp_picture_buf, PIX_FMT_RGB24, width, height );
                 //}
@@ -201,11 +205,15 @@ int RemoteCameraRtsp::Capture( Image &image )
             if ( !buffer.size() )
                 return( -1 );
 
+            AVPacket packet;
+            av_init_packet( &packet );
             int initialFrameCount = frameCount;
             while ( buffer.size() > 0 )
             {
                 int got_picture = false;
-                int len = avcodec_decode_video( codecContext, picture, &got_picture, buffer.head(), buffer.size() );
+                packet.data = buffer.head();
+                packet.size = buffer.size();
+                int len = avcodec_decode_video2( codecContext, picture, &got_picture, &packet );
                 if ( len < 0 )
                 {
                     if ( frameCount > initialFrameCount )
@@ -232,9 +240,9 @@ int RemoteCameraRtsp::Capture( Image &image )
 
                     if ( !img_convert_ctx )
                     {
-                        img_convert_ctx = sws_getContext( codecContext->width, codecContext->height, codecContext->pix_fmt, width, height, PIX_FMT_RGB24, SWS_BICUBIC, NULL, NULL, NULL );
+                        img_convert_ctx = sws_getCachedContext( NULL, codecContext->width, codecContext->height, codecContext->pix_fmt, width, height, PIX_FMT_RGB24, SWS_BICUBIC, NULL, NULL, NULL );
                         if ( !img_convert_ctx )
-                            Fatal( "Unable to initialise image scaling context" );
+                            Panic( "Unable to initialise image scaling context" );
                     }
 
                     sws_scale( img_convert_ctx, picture->data, picture->linesize, 0, height, tmp_picture->data, tmp_picture->linesize );
