@@ -1,5 +1,5 @@
 //
-// ZoneMinder RTSP Class Implementation, $Date: 2009-05-28 09:47:59 +0100 (Thu, 28 May 2009) $, $Revision: 2905 $
+// ZoneMinder RTSP Class Implementation, $Date: 2011-05-15 21:38:51 +0100 (Sun, 15 May 2011) $, $Revision: 3338 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -69,10 +69,10 @@ bool RtspThread::recvResponse( std::string &response )
 {
     if ( mRtspSocket.recv( response ) < 0 )
         Error( "Recv failed; %s", strerror(errno) );
-    Debug( 2, "Received RTSP response: %s (%d bytes)", response.c_str(), response.size() );
+    Debug( 2, "Received RTSP response: %s (%zd bytes)", response.c_str(), response.size() );
     float respVer = 0;
     int respCode = -1;
-    char respText[BUFSIZ];
+    char respText[ZM_NETWORK_BUFSIZ];
     if ( sscanf( response.c_str(), "RTSP/%f %3d %[^\r\n]\r\n", &respVer, &respCode, respText ) != 3 )
     {
         if ( isalnum(response[0]) )
@@ -81,7 +81,7 @@ bool RtspThread::recvResponse( std::string &response )
         }
         else
         {
-            Error( "Response parse failure, %d bytes follow", response.size() );
+            Error( "Response parse failure, %zd bytes follow", response.size() );
             if ( response.size() )
                 Hexdump( ZM_DBG_ERR, response.data(), min(response.size(),16) );
         }
@@ -99,7 +99,7 @@ int RtspThread::requestPorts()
 {
     if ( !smMinDataPort )
     {
-        char sql[BUFSIZ];
+        char sql[ZM_SQL_SML_BUFSIZ];
         strncpy( sql, "select Id from Monitors where Function != 'None' and Type = 'Remote' and Protocol = 'rtsp' and Method = 'rtpUni' order by Id asc", sizeof(sql) );
         if ( mysql_query( &dbconn, sql ) )
         {
@@ -147,7 +147,7 @@ int RtspThread::requestPorts()
             return( i );
         }
     }
-    Fatal( "Can assign RTP port, no ports left in pool" );
+    Panic( "Can assign RTP port, no ports left in pool" );
     return( -1 );
 }
 
@@ -184,7 +184,7 @@ RtspThread::RtspThread( int id, RtspMethod method, const std::string &protocol,
 
     mSsrc = rand();
 
-    Debug( 2, "RTSP Local SSRC is %lx", mSsrc );
+    Debug( 2, "RTSP Local SSRC is %x", mSsrc );
 
     if ( mMethod == RTP_RTSP_HTTP )
         mHttpSession = stringtf( "%d", rand() );
@@ -202,7 +202,7 @@ int RtspThread::run()
     std::string message;
     std::string response;
 
-    response.reserve( BUFSIZ );
+    response.reserve( ZM_NETWORK_BUFSIZ );
 
     if ( !mRtspSocket.connect( mHost.c_str(), strtol( mPort.c_str(), NULL, 10 ) ) )
         Fatal( "Unable to connect RTSP socket" );
@@ -243,7 +243,7 @@ int RtspThread::run()
             return( -1 );
         }
 
-        Debug( 2, "Received HTTP response: %s (%d bytes)", response.c_str(), response.size() );
+        Debug( 2, "Received HTTP response: %s (%zd bytes)", response.c_str(), response.size() );
         float respVer = 0;
         int respCode = -1;
         char respText[256];
@@ -255,7 +255,7 @@ int RtspThread::run()
             }
             else
             {
-                Error( "Response parse failure, %d bytes follow", response.size() );
+                Error( "Response parse failure, %zd bytes follow", response.size() );
                 if ( response.size() )
                     Hexdump( ZM_DBG_ERR, response.data(), min(response.size(),16) );
             }
@@ -328,14 +328,18 @@ int RtspThread::run()
     }
 #endif
 
-    U32 rtpClock = 0;
+    uint32_t rtpClock = 0;
     std::string trackUrl = mUrl;
     if ( mFormatContext->nb_streams >= 1 )
     {
         for ( int i = 0; i < mFormatContext->nb_streams; i++ )
         {
             SessionDescriptor::MediaDescriptor *mediaDesc = sessDesc->getStream( i );
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(51,2,1)
+            if ( mFormatContext->streams[i]->codec->codec_type == AVMEDIA_TYPE_VIDEO )
+#else
             if ( mFormatContext->streams[i]->codec->codec_type == CODEC_TYPE_VIDEO )
+#endif
             {
                 trackUrl += "/"+mediaDesc->getControlUrl();
                 rtpClock = mediaDesc->getClock();
@@ -369,7 +373,7 @@ int RtspThread::run()
         }
         default:
         {
-            Fatal( "Got unexpected method %d", mMethod );
+            Panic( "Got unexpected method %d", mMethod );
             break;
         }
     }
@@ -550,7 +554,7 @@ int RtspThread::run()
             Select select( double(config.http_timeout)/1000.0 );
             select.addReader( &mRtspSocket );
 
-            Buffer buffer( 10*BUFSIZ );
+            Buffer buffer( ZM_NETWORK_BUFSIZ );
             time_t lastKeepalive = time(NULL);
             std::string keepaliveMessage = "OPTIONS * RTSP/1.0\r\n";
             std::string keepaliveResponse = "RTSP/1.0 200 OK\r\n";
@@ -563,10 +567,10 @@ int RtspThread::run()
                     break;
                 }
 
-                static char tempBuffer[10*BUFSIZ];
+                static char tempBuffer[ZM_NETWORK_BUFSIZ];
                 ssize_t nBytes = mRtspSocket.recv( tempBuffer, sizeof(tempBuffer) );
                 buffer.append( tempBuffer, nBytes );
-                Debug( 4, "Read %d bytes on sd %d, %d total", nBytes, mRtspSocket.getReadDesc(), buffer.size() );
+                Debug( 4, "Read %zd bytes on sd %d, %d total", nBytes, mRtspSocket.getReadDesc(), buffer.size() );
 
                 while( buffer.size() > 0 )
                 {
@@ -578,7 +582,7 @@ int RtspThread::run()
                         Debug( 4, "Got %d bytes left, expecting %d byte packet on channel %d", buffer.size(), len, channel );
                         if ( buffer.size() < (len+4) )
                         {
-                            Debug( 4, "Missing %d bytes, rereading", (len+4)-nBytes );
+                            Debug( 4, "Missing %zd bytes, rereading", (len+4)-nBytes );
                             break;
                         }
                         if ( channel == remoteChannels[0] )
@@ -591,7 +595,7 @@ int RtspThread::run()
                         else if ( channel == remoteChannels[1] )
                         {
                             len = ntohs( *((unsigned short *)(buffer+2)) );
-                            Debug( 4, "Got %d bytes on control channel %d", nBytes, channel );
+                            Debug( 4, "Got %zd bytes on control channel %d", nBytes, channel );
                             rtpCtrlThread.recvPackets( buffer+4, len );
                         }
                         else
@@ -704,7 +708,7 @@ int RtspThread::run()
         }
         default:
         {
-            Fatal( "Got unexpected method %d", mMethod );
+            Panic( "Got unexpected method %d", mMethod );
             break;
         }
     }
