@@ -1,5 +1,5 @@
 /*
- * ZoneMinder regular expression class implementation, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+ * ZoneMinder regular expression class implementation, $Date: 2010-11-11 12:22:35 +0000 (Thu, 11 Nov 2010) $, $Revision: 3189 $
  * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
@@ -103,7 +103,7 @@ bool User::canAccess( int monitor_id )
 // Function to load a user from username and password
 User *zmLoadUser( const char *username, const char *password )
 {
-	char sql[BUFSIZ] = "";
+    char sql[ZM_SQL_SML_BUFSIZ] = "";
 
 	if ( password )
 	{
@@ -148,6 +148,16 @@ User *zmLoadUser( const char *username, const char *password )
 User *zmLoadAuthUser( const char *auth, bool use_remote_addr )
 {
 #if HAVE_DECL_MD5
+#ifdef HAVE_GCRYPT_H
+    // Special initialisation for libgcrypt
+    if ( !gcry_check_version( GCRYPT_VERSION ) )
+    {
+        Fatal( "Unable to initialise libgcrypt" );
+    }
+    gcry_control( GCRYCTL_DISABLE_SECMEM, 0 );
+    gcry_control( GCRYCTL_INITIALIZATION_FINISHED, 0 );
+#endif // HAVE_GCRYPT_H
+
 	const char *remote_addr = "";
 	if ( use_remote_addr )
 	{
@@ -160,7 +170,7 @@ User *zmLoadAuthUser( const char *auth, bool use_remote_addr )
 	}
 
 	Debug( 1, "Attempting to authenticate user from auth string '%s'", auth );
-	char sql[BUFSIZ] = "";
+    char sql[ZM_SQL_SML_BUFSIZ] = "";
 	snprintf( sql, sizeof(sql), "select Username, Password, Enabled, Stream+0, Events+0, Control+0, Monitors+0, System+0, MonitorIds from Users where Enabled = 1" );
 
 	if ( mysql_query( &dbconn, sql ) )
