@@ -1,5 +1,5 @@
 //
-// ZoneMinder Capture Daemon, $Date: 2009-04-14 21:18:57 +0100 (Tue, 14 Apr 2009) $, $Revision: 2848 $
+// ZoneMinder Capture Daemon, $Date: 2011-02-15 21:59:06 +0000 (Tue, 15 Feb 2011) $, $Revision: 3302 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -154,11 +154,14 @@ int main( int argc, char *argv[] )
 
 	Monitor **monitors = 0;
 	int n_monitors = 0;
+#if ZM_HAS_V4L
 	if ( device[0] )
 	{
 		n_monitors = Monitor::LoadLocalMonitors( device, monitors, Monitor::CAPTURE );
 	}
-	else if ( host[0] )
+	else
+#endif // ZM_HAS_V4L
+    if ( host[0] )
 	{
 		if ( !port )
 			port = "80";
@@ -289,6 +292,8 @@ int main( int argc, char *argv[] )
 	{
 		delete monitors[i];
 	}
+    delete monitors;
+	delete [] alarm_capture_delays;
 	delete [] capture_delays;
 	delete [] next_delays;
 	delete [] last_capture_times;
