@@ -1,5 +1,5 @@
 //
-// ZoneMinder Control Utility, $Date: 2009-04-14 21:18:57 +0100 (Tue, 14 Apr 2009) $, $Revision: 2848 $
+// ZoneMinder Control Utility, $Date: 2011-02-15 21:59:06 +0000 (Tue, 15 Feb 2011) $, $Revision: 3302 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -190,11 +190,13 @@ int main( int argc, char *argv[] )
 	char *username = 0;
 	char *password = 0;
 	char *auth = 0;
-#ifdef ZM_V4L2
+#if ZM_HAS_V4L
+#if ZM_HAS_V4L2
     int v4lVersion = 2;
-#else // ZM_V4L2
+#elif ZM_HAS_V4L1
     int v4lVersion = 1;
-#endif // ZM_V4L2
+#endif // ZM_HAS_V4L2/1
+#endif // ZM_HAS_V4L
 	while (1)
 	{
 		int option_index = 0;
@@ -306,9 +308,11 @@ int main( int argc, char *argv[] )
 			case 'A':
 				auth = optarg;
 				break;
+#if ZM_HAS_V4L
 			case 'V':
 				v4lVersion = (atoi(optarg)==1)?1:2;
 				break;
+#endif // ZM_HAS_V4L
 			case 'h':
 				Usage( 0 );
 				break;
@@ -493,9 +497,9 @@ int main( int argc, char *argv[] )
 				if ( verbose )
 				{
 					if ( image_idx == -1 )
-						printf( "Dumping last image captured to %s.jpg", monitor->Name() );
+						printf( "Dumping last image captured to Monitor%d.jpg", monitor->Id() );
 					else
-						printf( "Dumping buffer image %d to %s.jpg", image_idx, monitor->Name() );
+						printf( "Dumping buffer image %d to Monitor%d.jpg", image_idx, monitor->Id() );
 					if ( scale != -1 )
 						printf( ", scaling by %d%%", scale );
 					printf( "\n" );
@@ -505,7 +509,7 @@ int main( int argc, char *argv[] )
 			if ( function & ZMU_ZONES )
 			{
 				if ( verbose )
-					printf( "Dumping zone image to %s-Zones.jpg\n", monitor->Name() );
+					printf( "Dumping zone image to Zones%d.jpg\n", monitor->Id() );
 				monitor->DumpZoneImage( zoneString );
 			}
 			if ( function & ZMU_ALARM )
@@ -658,15 +662,20 @@ int main( int argc, char *argv[] )
 	{
 		if ( function & ZMU_QUERY )
 		{
+#if ZM_HAS_V4L
 			char vidString[0x10000] = "";
 			bool ok = LocalCamera::GetCurrentSettings( device, vidString, v4lVersion, verbose );
 			printf( "%s", vidString );
 			exit( ok?0:-1 );
+#else // ZM_HAS_V4L
+			fprintf( stderr, "Error, video4linux is required for device querying\n" );
+            exit( -1 );
+#endif // ZM_HAS_V4L
 		}
 
 		if ( function & ZMU_LIST )
 		{
-			char sql[BUFSIZ];
+           char sql[ZM_SQL_SML_BUFSIZ];
 			strncpy( sql, "select Id, Function+0 from Monitors", sizeof(sql) );
 			if ( !verbose )
 			{
