@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web function library, $Date: 2009-05-06 10:48:01 +0100 (Wed, 06 May 2009) $, $Revision: 2860 $
+// ZoneMinder web function library, $Date: 2011-05-23 16:15:37 +0100 (Mon, 23 May 2011) $, $Revision: 3351 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -32,10 +32,6 @@ if ( version_compare( phpversion(), "4.3.0", "<") )
 function userLogin( $username, $password="", $passwordHashed=false )
 {
     global $user, $cookies;
-    if ( version_compare( phpversion(), "4.1.0", "<") )
-    {
-        global $_SESSION, $_SERVER;
-    }
 
     $dbUsername = dbEscape($username);
     $dbPassword = dbEscape($password);
@@ -81,10 +77,6 @@ function userLogin( $username, $password="", $passwordHashed=false )
 function userLogout()
 {
     global $user;
-    if ( version_compare( phpversion(), "4.1.0", "<") )
-    {
-        global $_SESSION;
-    }
 
     unset( $_SESSION['user'] );
     unset( $user );
@@ -103,10 +95,6 @@ function noCacheHeaders()
 
 function getAuthUser( $auth )
 {
-    if ( version_compare( phpversion(), "4.1.0", "<") )
-    {
-        global $_SERVER;
-    }
     if ( ZM_OPT_USE_AUTH && ZM_AUTH_RELAY == "hashed" && !empty($auth) )
     {
         $remoteAddr = "";
@@ -143,11 +131,6 @@ function getAuthUser( $auth )
 
 function generateAuthHash( $useRemoteAddr )
 {
-    if ( version_compare( phpversion(), "4.1.0", "<") )
-    {
-        global $_SESSION;
-    }
-
     if ( ZM_OPT_USE_AUTH && ZM_AUTH_RELAY == "hashed" )
     {
         $time = localtime();
@@ -168,13 +151,8 @@ function generateAuthHash( $useRemoteAddr )
     return( $auth );
 }
 
-function getStreamSrc( $args, $querySep='&' )
+function getStreamSrc( $args, $querySep='&amp;' )
 {
-    if ( version_compare( phpversion(), "4.1.0", "<") )
-    {
-        global $_SESSION, $_SERVER;
-    }
-
     $streamSrc = ZM_BASE_URL.ZM_PATH_ZMS;
 
     if ( ZM_OPT_USE_AUTH )
@@ -193,7 +171,7 @@ function getStreamSrc( $args, $querySep='&' )
             $args[] = "user=".$_SESSION['username'];
         }
     }
-    if ( !empty($GLOBALS['connkey']) )
+    if ( !in_array( "mode=single", $args ) && !empty($GLOBALS['connkey']) )
     {   
         $args[] = "connkey=".$GLOBALS['connkey'];
     }       
@@ -309,7 +287,7 @@ type="<?= $mimeType ?>">
 <embed type="<?= $mimeType ?>"
 src="<?= $src ?>"
 pluginspage="http://www.apple.com/quicktime/download/"
-name="<?= validhtmlStr($title) ?>"
+name="<?= validHtmlStr($title) ?>"
 width="<?= validInt($width) ?>"
 height="<?= validInt($height) ?>"
 autoplay="true"
@@ -466,11 +444,6 @@ function outputControlStill( $src, $width, $height, $monitor, $scale, $target )
 
 function getZmuCommand( $args )
 {
-    if ( version_compare( phpversion(), "4.1.0", "<") )
-    {
-        global $_SESSION;
-    }
-
     $zmuCommand = ZMU_PATH;
 
     if ( ZM_OPT_USE_AUTH )
@@ -498,7 +471,7 @@ function visibleMonitor( $mid )
 {
     global $user;
 
-    return( empty($user['MonitorIds']) || in_array( $mid, split( ',', $user['MonitorIds'] ) ) );
+    return( empty($user['MonitorIds']) || in_array( $mid, explode( ',', $user['MonitorIds'] ) ) );
 }
 
 function canView( $area, $mid=false )
@@ -518,12 +491,25 @@ function canEdit( $area, $mid=false )
 function getEventPath( $event )
 {
     if ( ZM_USE_DEEP_STORAGE )
-        $eventPath = ZM_DIR_EVENTS.'/'.$event['MonitorId'].'/'.strftime( "%y/%m/%d/%H/%M/%S", strtotime($event['StartTime']) );
+        $eventPath = $event['MonitorId'].'/'.strftime( "%y/%m/%d/%H/%M/%S", strtotime($event['StartTime']) );
     else
-        $eventPath = ZM_DIR_EVENTS.'/'.$event['MonitorId'].'/'.$event['Id'];
+        $eventPath = $event['MonitorId'].'/'.$event['Id'];
     return( $eventPath );
 }
 
+
+function deletePath( $path )
+{
+    if ( is_dir( $path ) )
+    {
+        system( escapeshellcmd( "rm -rf ".$path ) );
+    }
+    else
+    {
+        unlink( $path );
+    }
+}
+
 function deleteEvent( $eid, $mid=false )
 {
     global $user;
@@ -542,22 +528,22 @@ function deleteEvent( $eid, $mid=false )
             {
                 if ( $id_files = glob( ZM_DIR_EVENTS.'/'.$mid.'/*/*/*/.'.$eid ) )
                     $eventPath = preg_replace( "/\.$eid$/", readlink($id_files[0]), $id_files[0] );
-                system( escapeshellcmd( "rm -rf ".$eventPath ) );
-                unlink( $id_files[0] );
+                deletePath( $eventPath );
+                deletePath( $id_files[0] );
                 $pathParts = explode(  '/', $eventPath );
                 for ( $i = count($pathParts)-1; $i >= 2; $i-- )
                 {
                     $deletePath = join( '/', array_slice( $pathParts, 0, $i ) );
                     if ( !glob( $deletePath."/*" ) )
                     {
-                        system( escapeshellcmd( "rm -rf ".$deletePath ) );
+                        deletePath( $deletePath );
                     }
                 }
             }
             else
             {
                 $eventPath = ZM_DIR_EVENTS.'/'.$mid.'/'.$eid;
-                system( escapeshellcmd( "rm -rf ".$eventPath ) );
+                deletePath( $eventPath );
             }
         }
     }
@@ -615,11 +601,6 @@ function truncText( $text, $length, $deslash=1 )
 
 function buildSelect( $name, $contents, $behaviours=false )
 {
-    if ( version_compare( phpversion(), "4.1.0", "<") )
-    {   
-        global $_SESSION;
-    }   
-
     $value = "";
     if ( preg_match( "/^\s*(\w+)\s*(\[.*\])?\s*$/", $name, $matches ) && count($matches) > 2 )
     {
@@ -800,44 +781,54 @@ function getFormChanges( $values, $newValues, $types=false, $columns=false )
 
 function getBrowser( &$browser, &$version )
 {
-    if ( version_compare( phpversion(), "4.1.0", "<") )
+    if ( isset($_SESSION['browser']) )
     {
-        global $_SERVER;
-    }
-
-    if (ereg( 'MSIE ([0-9].[0-9]{1,2})',$_SERVER['HTTP_USER_AGENT'],$logVersion))
-    {
-        $version = $logVersion[1];
-        $browser = 'ie';
-    }
-    elseif (ereg( 'Safari/([0-9.]+)',$_SERVER['HTTP_USER_AGENT'],$logVersion))
-    {
-        $version = $logVersion[1];
-        $browser = 'safari';
-    }
-        elseif (ereg( 'Konqueror/([0-9.]+)',$_SERVER['HTTP_USER_AGENT'],$logVersion))
-        {
-                $version = $logVersion[1];
-                $browser = 'konqueror';
-        }
-    elseif (ereg( 'Opera ([0-9].[0-9]{1,2})',$_SERVER['HTTP_USER_AGENT'],$logVersion))
-    {
-        $version = $logVersion[1];
-        $browser = 'opera';
-    }
-    elseif (ereg( 'Mozilla/([0-9].[0-9]{1,2})',$_SERVER['HTTP_USER_AGENT'],$logVersion))
-    {
-        $version = $logVersion[1];
-        $browser = 'mozilla';
+        $browser = $_SESSION['browser'];
+        $version = $_SESSION['version'];
     }
     else
     {
-        $version = 0;
-        $browser = 'unknown';
+        if ( preg_match( '/MSIE ([0-9].[0-9]{1,2})/', $_SERVER['HTTP_USER_AGENT'], $logVersion) )
+        {
+            $version = $logVersion[1];
+            $browser = 'ie';
+        }
+        elseif ( preg_match( '/Chrome\/([0-9.]+)/', $_SERVER['HTTP_USER_AGENT'], $logVersion) )
+        {
+            $version = $logVersion[1];
+            $browser = 'chrome';
+        }
+        elseif ( preg_match( '/Safari\/([0-9.]+)/', $_SERVER['HTTP_USER_AGENT'], $logVersion) )
+        {
+            $version = $logVersion[1];
+            $browser = 'safari';
+        }
+        elseif ( preg_match( '/Opera[ \/]([0-9].[0-9]{1,2})/', $_SERVER['HTTP_USER_AGENT'], $logVersion) )
+        {
+            $version = $logVersion[1];
+            $browser = 'opera';
+        }
+        elseif ( preg_match( '/Konqueror\/([0-9.]+)/', $_SERVER['HTTP_USER_AGENT'], $logVersion) )
+        {
+            $version = $logVersion[1];
+            $browser = 'konqueror';
+        }
+        elseif ( preg_match( '/Mozilla\/([0-9].[0-9]{1,2})/', $_SERVER['HTTP_USER_AGENT'], $logVersion) )
+        {
+            $version = $logVersion[1];
+            $browser = 'mozilla';
+        }
+        else
+        {
+            $version = 0;
+            $browser = 'unknown';
+        }
+        $_SESSION['browser'] = $browser;
+        $_SESSION['version'] = $version;
     }
 }
 
-function isNetscape()
+function isMozilla()
 {
     getBrowser( $browser, $version );
 
@@ -858,24 +849,41 @@ function isInternetExplorer()
     return( $browser == "ie" );
 }
 
+function isChrome()
+{
+    getBrowser( $browser, $version );
+
+    return( $browser == "chrome" );
+}
+
+function isOpera()
+{
+    getBrowser( $browser, $version );
+
+    return( $browser == "opera" );
+}
+
+function isSafari()
+{
+    getBrowser( $browser, $version );
+
+    return( $browser == "safari" );
+}
+
 function isWindows()
 {
-    if ( version_compare( phpversion(), "4.1.0", "<") )
-    {
-        global $_SERVER;
-    }
-
     return ( preg_match( '/Win/', $_SERVER['HTTP_USER_AGENT'] ) );
 }
 
 function canStreamIframe()
 {
-   return (isKonqueror());
+   return( isKonqueror() );
 }
 
 function canStreamNative()
 {
-   return( ZM_CAN_STREAM == "yes" || ( ZM_CAN_STREAM == "auto" && (isNetscape() || isKonqueror()) ) );
+   // Chrome can display the stream, but then it blocks everything else (Chrome bug 5876)
+   return( ZM_WEB_CAN_STREAM == "yes" || ( ZM_WEB_CAN_STREAM == "auto" && (!isInternetExplorer() && !isChrome()) ) );
 }
 
 function canStreamApplet()
@@ -932,7 +940,7 @@ function zmcControl( $monitor, $mode=false )
     $row = dbFetchOne( $sql );
     $activeCount = $row['ActiveCount'];
 
-    if ( !$activeCount )
+    if ( !$activeCount || $mode == "stop" )
     {
         daemonControl( "stop", "zmc", $zmcArgs );
     }
@@ -953,41 +961,21 @@ function zmaControl( $monitor, $mode=false )
         $sql = "select C.*, M.* from Monitors as M left join Controls as C on (M.ControlId = C.Id ) where M.Id = '".dbEscape($monitor)."'";
         $monitor = dbFetchOne( $sql );
     }
-    switch ( $monitor['Function'] )
+    if ( !$monitor || $monitor['Function'] == 'None' || $monitor['Function'] == 'Monitor' || $mode == "stop" )
     {
-        case 'Modect' :
-        case 'Record' :
-        case 'Mocord' :
-        case 'Nodect' :
+        if ( ZM_OPT_CONTROL )
         {
-            if ( $mode == "restart" )
-            {
-                if ( ZM_OPT_CONTROL )
-                {
-                    daemonControl( "stop", "zmtrack.pl", "-m ".$monitor['Id'] );
-                }
-                daemonControl( "stop", "zma", "-m ".$monitor['Id'] );
-                if ( ZM_OPT_FRAME_SERVER )
-                {
-                    daemonControl( "stop", "zmf", "-m ".$monitor['Id'] );
-                }
-            }
-            if ( ZM_OPT_FRAME_SERVER )
-            {
-                daemonControl( "start", "zmf", "-m ".$monitor['Id'] );
-            }
-            daemonControl( "start", "zma", "-m ".$monitor['Id'] );
-            if ( ZM_OPT_CONTROL && $monitor['Controllable'] && $monitor['TrackMotion'] && ( $monitor['Function'] == 'Modect' || $monitor['Function'] == 'Mocord' ) )
-            {
-                daemonControl( "start", "zmtrack.pl", "-m ".$monitor['Id'] );
-            }
-            if ( $mode == "reload" )
-            {
-                daemonControl( "reload", "zma", "-m ".$monitor['Id'] );
-            }
-            break;
+            daemonControl( "stop", "zmtrack.pl", "-m ".$monitor['Id'] );
         }
-        default :
+        daemonControl( "stop", "zma", "-m ".$monitor['Id'] );
+        if ( ZM_OPT_FRAME_SERVER )
+        {
+            daemonControl( "stop", "zmf", "-m ".$monitor['Id'] );
+        }
+    }
+    else
+    {
+        if ( $mode == "restart" )
         {
             if ( ZM_OPT_CONTROL )
             {
@@ -998,7 +986,19 @@ function zmaControl( $monitor, $mode=false )
             {
                 daemonControl( "stop", "zmf", "-m ".$monitor['Id'] );
             }
-            break;
+        }
+        if ( ZM_OPT_FRAME_SERVER )
+        {
+            daemonControl( "start", "zmf", "-m ".$monitor['Id'] );
+        }
+        daemonControl( "start", "zma", "-m ".$monitor['Id'] );
+        if ( ZM_OPT_CONTROL && $monitor['Controllable'] && $monitor['TrackMotion'] && ( $monitor['Function'] == 'Modect' || $monitor['Function'] == 'Mocord' ) )
+        {
+            daemonControl( "start", "zmtrack.pl", "-m ".$monitor['Id'] );
+        }
+        if ( $mode == "reload" )
+        {
+            daemonControl( "reload", "zma", "-m ".$monitor['Id'] );
         }
     }
 }
@@ -1105,17 +1105,20 @@ function getImageSrc( $event, $frame, $scale=SCALE_BASE, $captureOnly=false, $ov
 
     $analImage = sprintf( "%0".ZM_EVENT_IMAGE_DIGITS."d-analyse.jpg", $frame['FrameId'] );
     $analPath = $eventPath.'/'.$analImage;
+    $analFile =  ZM_DIR_EVENTS."/".$analPath;
     $thumbAnalPath = ZM_DIR_IMAGES.'/'.$event['Id'].'-'.$analImage;
     //echo "AI:$analImage, AP:$analPath, TAP:$thumbAnalPath<br>";
 
     $alarmFrame = $frame['Type']=='Alarm';
 
-    $hasAnalImage = $alarmFrame && file_exists( $analPath ) && filesize( $analPath );
+    $hasAnalImage = $alarmFrame && file_exists( $analFile ) && filesize( $analFile );
     $isAnalImage = $hasAnalImage && !$captureOnly;
 
-    if ( $scale >= SCALE_BASE || !file_exists( ZM_PATH_NETPBM."/jpegtopnm" ) )
+    if ( !ZM_WEB_SCALE_THUMBS || $scale >= SCALE_BASE || !function_exists( 'imagecreatefromjpeg' ) )
     {
         $imagePath = $thumbPath = $isAnalImage?$analPath:$captPath;
+        $imageFile = ZM_DIR_EVENTS."/".$imagePath;
+        $thumbFile = ZM_DIR_EVENTS."/".$thumbPath;
     }
     else
     {
@@ -1139,17 +1142,23 @@ function getImageSrc( $event, $frame, $scale=SCALE_BASE, $captureOnly=false, $ov
             $thumbPath = $thumbCaptPath;
         }
 
-        if ( !file_exists( $thumbPath ) || !filesize( $thumbPath ) )
+        $imageFile = ZM_DIR_EVENTS."/".$imagePath;
+        //$thumbFile = ZM_DIR_EVENTS."/".$thumbPath;
+        $thumbFile = $thumbPath;
+        if ( $overwrite || !file_exists( $thumbFile ) || !filesize( $thumbFile ) )
         {
-            if ( ZM_WEB_SCALE_THUMBS )
-            {
-                $command = ZM_PATH_NETPBM."/jpegtopnm -quiet -dct fast $imagePath | ".ZM_PATH_NETPBM."/pnmscalefixed -quiet $fraction | ".ZM_PATH_NETPBM."/pnmtojpeg -quiet -dct=fast > $thumbPath";
-                exec( $command );
-            }
-            else
-            {
-                $imagePath = $thumbPath = $isAnalImage?$analPath:$captPath;
-            }
+            // Get new dimensions
+            list( $imageWidth, $imageHeight ) = getimagesize( $imageFile );
+            $thumbWidth = $imageWidth * $fraction;
+            $thumbHeight = $imageHeight * $fraction;
+
+            // Resample
+            $thumbImage = imagecreatetruecolor( $thumbWidth, $thumbHeight );
+            $image = imagecreatefromjpeg( $imageFile );
+            imagecopyresampled( $thumbImage, $image, 0, 0, 0, 0, $thumbWidth, $thumbHeight, $imageWidth, $imageHeight );
+
+            if ( !imagejpeg( $thumbImage, $thumbFile ) )
+                error_log( "Can't create thumbnail '$thumbPath'" );
         }
     }
 
@@ -1157,6 +1166,8 @@ function getImageSrc( $event, $frame, $scale=SCALE_BASE, $captureOnly=false, $ov
         'eventPath' => $eventPath,
         'imagePath' => $imagePath,
         'thumbPath' => $thumbPath,
+        'imageFile' => $imageFile,
+        'thumbFile' => $thumbFile,
         'imageClass' => $alarmFrame?"alarm":"normal",
         'isAnalImage' => $isAnalImage,
         'hasAnalImage' => $hasAnalImage,
@@ -1167,9 +1178,23 @@ function getImageSrc( $event, $frame, $scale=SCALE_BASE, $captureOnly=false, $ov
     return( $imageData );
 }
 
+function viewImagePath( $path, $querySep='&amp;' )
+{
+    if ( strncmp( $path, ZM_DIR_IMAGES, strlen(ZM_DIR_IMAGES) ) == 0 )
+    {
+        // Thumbnails
+        return( $path );
+    }
+    elseif ( strpos( ZM_DIR_EVENTS, '/' ) === 0 )
+    {
+        return( '?view=image'.$querySep.'path='.$path );
+    }
+    return( ZM_DIR_EVENTS.'/'.$path );
+}
+
 function createListThumbnail( $event, $overwrite=false )
 {
-    $sql = "select * from Frames where EventId = '".$event['Id']."' and Score = '".$event['MaxScore']."' order by FrameId limit 0,1";
+    $sql = "select * from Frames where EventId = '".$event['Id']."' and Score = '".$event['MaxScore']."' order by FrameId limit 1";
     if ( !($frame = dbFetchOne( $sql )) )
         return( false );
 
@@ -1192,7 +1217,7 @@ function createListThumbnail( $event, $overwrite=false )
         die( "No thumbnail width or height specified, please check in Options->Web" );
     }
 
-    $imageData = getImageSrc( $event, $frame, $scale );
+    $imageData = getImageSrc( $event, $frame, $scale, false, $overwrite );
     $thumbData = $frame;
     $thumbData['Path'] = $imageData['thumbPath'];
     $thumbData['Width'] = (int)$thumbWidth;
@@ -1257,15 +1282,10 @@ function monitorLimitSql()
     return( $midSql );
 }
 
-function parseSort( $saveToSession=false, $querySep='&' )
+function parseSort( $saveToSession=false, $querySep='&amp;' )
 {
     global $sortQuery, $sortColumn, $sortOrder; // Outputs
 
-    if ( version_compare( phpversion(), "4.1.0", "<") )
-    {
-        global $_SESSION;
-    }
-
     if ( empty($_REQUEST['sort_field']) )
     {
         $_REQUEST['sort_field'] = ZM_WEB_EVENT_SORT_FIELD;
@@ -1325,13 +1345,8 @@ function parseSort( $saveToSession=false, $querySep='&' )
     }
 }
 
-function parseFilter( &$filter, $saveToSession=false, $querySep='&' )
+function parseFilter( &$filter, $saveToSession=false, $querySep='&amp;' )
 {
-    if ( version_compare( phpversion(), "4.1.0", "<") )
-    {
-        global $_SESSION;
-    }
-
     $filter['query'] = ''; 
     $filter['sql'] = '';
     $filter['fields'] = '';
@@ -1457,7 +1472,7 @@ function parseFilter( &$filter, $saveToSession=false, $querySep='&' )
             {
                 $filter['query'] .= $querySep."filter[terms][$i][cbr]=".urlencode($filter['terms'][$i]['cbr']);
                 $filter['sql'] .= " ".str_repeat( ")", $filter['terms'][$i]['cbr'] )." ";
-                $filter['fields'] .= "<input type=\"hidden\" name=filter[terms][$i][cbr]\" value=\"".htmlspecialchars($filter['terms'][$i]['cbr'])."\"/>\n";
+                $filter['fields'] .= "<input type=\"hidden\" name=\"filter[terms][$i][cbr]\" value=\"".htmlspecialchars($filter['terms'][$i]['cbr'])."\"/>\n";
             }
         }
         if ( $filter['sql'] )
@@ -1493,7 +1508,7 @@ function delFilterTerm( $filter, $position )
     return( $filter );
 }
 
-function getPagination( $pages, $page, $maxShortcuts, $query, $querySep='&' )
+function getPagination( $pages, $page, $maxShortcuts, $query, $querySep='&amp;' )
 {
     global $view;
 
@@ -1571,7 +1586,7 @@ function getPagination( $pages, $page, $maxShortcuts, $query, $querySep='&' )
     return( $pageText );
 }
 
-function sortHeader( $field, $querySep='&' )
+function sortHeader( $field, $querySep='&amp;' )
 {
     global $view;
     return( '?view='.$view.$querySep.'page=1'.$_REQUEST['filter']['query'].$querySep.'sort_field='.$field.$querySep.'sort_asc='.($_REQUEST['sort_field'] == $field?!$_REQUEST['sort_asc']:0).$querySep.'limit='.$_REQUEST['limit'] );
@@ -1620,7 +1635,7 @@ function sidField()
 {
     if ( SID )
     {
-        list( $sessname, $sessid ) = split( "=", SID );
+        list( $sessname, $sessid ) = explode( "=", SID );
 ?>
 <input type="hidden" name="<?= $sessname ?>" value="<?= $sessid ?>"/>
 <?php
@@ -2086,7 +2101,7 @@ function initX10Status()
 
             $x10Output = exec( escapeshellcmd( $command ) );
         }
-        foreach ( split( "\n", $x10Output ) as $x10Response )
+        foreach ( explode( "\n", $x10Output ) as $x10Response )
         {
             if ( preg_match( "/^(\d+)\s+(.+)$/", $x10Response, $matches ) )
             {
@@ -2153,10 +2168,33 @@ function isVector ( &$array )
     return( true );
 }
 
+function checkJsonError()
+{
+    switch( json_last_error() )
+    {
+        case JSON_ERROR_DEPTH :
+            die( "Unable to decode JSON string '$value', maximum stack depth exceeded" );
+        case JSON_ERROR_CTRL_CHAR :
+            die( "Unable to decode JSON string '$value', unexpected control character found" );
+        case JSON_ERROR_STATE_MISMATCH :
+            die( "Unable to decode JSON string '$value', invalid or malformed JSON" );
+        case JSON_ERROR_SYNTAX :
+            die( "Unable to decode JSON string '$value', syntax error" );
+        default :
+            die( "Unable to decode JSON string '$value', unexpected error ".json_last_error() );
+        case JSON_ERROR_NONE:
+            break;
+    }
+}
+
 function jsonEncode( &$value )
 {
     if ( function_exists('json_encode') )
-        return( json_encode( $value ) );
+    {
+        $string = json_encode( $value );
+        checkJsonError();
+        return( $string );
+    }
 
     switch ( gettype($value) )
     {
@@ -2166,11 +2204,11 @@ function jsonEncode( &$value )
         case 'boolean':
             return( $value?'true':'false' );
         case 'string':
-            return( '"'.preg_replace( "/\r?\n/", '\\n', addcslashes($value,'"\'\\/') ).'"' );
+            return( '"'.preg_replace( "/\r?\n/", '\\n', addcslashes($value,'"\\/') ).'"' );
         case 'NULL':
             return( 'null' );
         case 'object':
-            return( '"Object '.addcslashes(get_class($value),'"\'\\/').'"' );
+            return( '"Object '.addcslashes(get_class($value),'"\\/').'"' );
         case 'array':
             if ( isVector( $value ) )
                 return( '['.join( ',', array_map( 'jsonEncode', $value) ).']' );
@@ -2181,15 +2219,61 @@ function jsonEncode( &$value )
                 {
                     if ( $result != '{' )
                         $result .= ',';
-                    $result .= jsonEncode( $subkey ).':'.jsonEncode( $subvalue );
+                    $result .= '"'.$subkey.'":'.jsonEncode( $subvalue );
                 }
                 return( $result.'}' );
             }
         default:
-            return( '"'.addcslashes(gettype($value),'"\'\\/').'"' );
+            return( '"'.addcslashes(gettype($value),'"\\/').'"' );
     }
 }
 
+function jsonDecode( $value )
+{
+    if ( function_exists('json_decode') )
+    {
+        $object = json_decode( $value, true );
+        checkJsonError();
+        return( $object );
+    }
+
+    $comment = false;
+    $unescape = false;
+    $out = '$result=';
+    for ( $i = 0; $i < strlen($value); $i++ )
+    {
+        if ( !$comment )
+        {
+            if ( ($value[$i] == '{') || ($value[$i] == '[') )
+                $out .= ' array(';
+            else if ( ($value[$i] == '}') || ($value[$i] == ']') )
+                $out .= ')';
+            else if ( $value[$i] == ':' )
+                $out .= '=>';
+            else
+                $out .= $value[$i];         
+        }
+        else if ( !$unescape )
+        {
+            if ( $value[$i] == '\\' )
+                $unescape = true;
+            else
+                $out .= $value[$i];
+        }
+        else
+        {
+            if ( $value[$i] != '/' )
+                $out .= '\\';
+            $out .= $value[$i];
+            $unescape = false;
+        }
+        if ( $value[$i] == '"' )
+            $comment = !$comment;
+    }
+    eval( $out.';' );
+    return( $result );
+}
+
 define( 'HTTP_STATUS_OK', 200 );
 define( 'HTTP_STATUS_BAD_REQUEST', 400 );
 define( 'HTTP_STATUS_FORBIDDEN', 403 );
