@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web UK English language file, $Date: 2009-05-24 11:00:20 +0100 (Sun, 24 May 2009) $, $Revision: 2889 $
+// ZoneMinder web UK English language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -127,7 +127,7 @@ $SLANG = array(
     'BadAlarmMaxFPS'       => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'           => 'Channel must be set to an integer of zero or more',
     'BadDevice'            => 'Device must be set to a valid value',
-    'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 100 or more',
+    'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
     'BadFrameSkip'         => 'Frame skip count must be an integer of zero or more',
     'BadHeight'            => 'Height must be set to a valid value',
@@ -246,6 +246,7 @@ $SLANG = array(
     'Dimensions'           => 'Rozmry',
     'DisableAlarms'        => 'Zakzat alarmy',
     'Disk'                 => 'Disk',
+    'Display'              => 'Display',                // Added - 2011-01-30
     'Donate'               => 'Prosm podpote',
     'DonateAlready'        => 'Ne, u jsem podpoil',
     'DonateEnticement'     => 'Ji njakou dobu pouvte software ZoneMinder k ochran svho majetku a pedpokldm, e jej shledvte uitenm. Pestoe je ZoneMinder, znovu pipomnm, zdarma a voln en software, stoj jeho vvoj a podpora njak penze. Pokud byste chtl/a podpoit budouc vvoj a nov monosti softwaru, prosm zvate darovn finann pomoci. Darovn je, samozejm, dobrovoln, ale zato velmi cenn mete pispt jakou stkou chcete.<br><br>Pokud mte zjem podpoit n tm, prosm, vyberte ne uvedenou monost, nebo navtivte http://www.zoneminder.com/donate.html.<br><br>Dkuji Vm e jste si vybral/a software ZoneMinder a nezapomete navtvit frum na ZoneMinder.com pro podporu a nvrhy jak udlat ZoneMinder jet lepm ne je dnes.',
@@ -547,6 +548,7 @@ $SLANG = array(
     'Rewind'               => 'Rewind',
     'RotateLeft'           => 'Otoit vlevo',
     'RotateRight'          => 'Otoit vpravo',
+    'RunLocalUpdate'       => 'Please run zmupdate.pl to update', // Added - 2011-05-25
     'RunMode'              => 'Reim',
     'RunState'             => 'Stav',
     'Running'              => 'B',
@@ -568,6 +570,7 @@ $SLANG = array(
     'ShowTimeline'         => 'Zobrazit asovou linii ',
     'SignalCheckColour'    => 'Signal Check Colour',
     'Size'                 => 'Velikost',
+    'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
     'Sleep'                => 'Spt',
     'SortAsc'              => 'Vzestupn',
     'SortBy'               => 'adit dle',
@@ -693,6 +696,7 @@ $CLANG = array(
     'MonitorCount'         => '%1$s %2$s', // For example '4 Monitors' (from Vlang below)
     'MonitorFunction'      => 'Funkce %1$s kamery',
     'RunningRecentVer'     => 'Pouvte posledn verzi ZoneMinder, v%s.',
+    'VersionMismatch'      => 'Version mismatch, system is version %1$s, database is %2$s.', // Added - 2011-05-25
 );
 
 // The next section allows you to describe a series of word ending and counts used to 
