@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web German language file, $Date: 2009-05-24 11:00:20 +0100 (Sun, 24 May 2009) $, $Revision: 2889 $
+// ZoneMinder web German language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -127,7 +127,7 @@ $SLANG = array(
     'BadAlarmMaxFPS'       => 'Alarm-Maximum-FPS muss eine positive Ganzzahl oder eine Gleitkommazahl sein',
     'BadChannel'           => 'Der Kanal muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
     'BadDevice'            => 'Das Ger&auml;t muss eine g&uuml;ltige Systemresource sein',
-    'BadFPSReportInterval' => 'Der FPS-Intervall-Puffer-Z&auml;hler muss ganzzahlig 100 oder gr&ouml;&szlig;er sein',
+    'BadFPSReportInterval' => 'Der FPS-Intervall-Puffer-Z&auml;hler muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
     'BadFormat'            => 'Das Format muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
     'BadFrameSkip'         => 'Der Auslassz&auml;hler f&uuml;r Frames muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
     'BadHeight'            => 'Die H&ouml;he muss auf einen g&uuml;ltigen Wert eingestellt sein',
@@ -246,6 +246,7 @@ $SLANG = array(
     'Dimensions'           => 'Abmessungen',
     'DisableAlarms'        => 'Alarme abschalten',
     'Disk'                 => 'Disk',
+    'Display'              => 'Display',                // Added - 2011-01-30
     'Donate'               => 'Bitte spenden Sie.',
     'DonateAlready'        => 'Nein, ich habe schon gespendet',
     'DonateEnticement'     => 'Sie benutzen ZoneMinder nun schon eine Weile und es ist hoffentlich eine n&uuml;tzliche Applikation zur Verbesserung Ihrer Heim- oder Arbeitssicherheit. Obwohl ZoneMinder eine freie Open-Source-Software ist und bleiben wird, entstehen Kosten bei der Entwicklung und dem Support.<br><br>Falls Sie ZoneMinder fr Weiterentwicklung in der Zukunft unterst&uuml;tzen m&ouml;chten, denken Sie bitte ber eine Spende f&uuml;r das Projekt unter der Webadresse http://www.zoneminder.com/donate.html oder &uuml;ber nachfolgend stehende Option nach. Spenden sind, wie der Name schon sagt, immer freiwillig. Dem Projekt helfen kleine genauso wie gr&ouml;&szlig;ere Spenden sehr weiter und ein herzlicher Dank ist jedem Spender sicher.<br><br>Vielen Dank daf&uuml;r, dass sie ZoneMinder benutzen. Vergessen Sie nicht die Foren unter ZoneMinder.com, um Support zu erhalten und Ihre Erfahrung mit ZoneMinder zu verbessern!',
@@ -547,6 +548,7 @@ $SLANG = array(
     'Rewind'               => 'Zur&uuml;ckspulen',
     'RotateLeft'           => 'Drehung links',
     'RotateRight'          => 'Drehung rechts',
+    'RunLocalUpdate'       => 'Please run zmupdate.pl to update', // Added - 2011-05-25
     'RunMode'              => 'Betriebsmodus',
     'RunState'             => 'Laufender Status',
     'Running'              => 'In Betrieb',
@@ -568,6 +570,7 @@ $SLANG = array(
     'ShowTimeline'         => 'Zeige Zeitlinie',
     'SignalCheckColour'    => 'Farbe des Signalchecks',
     'Size'                 => 'Gr&ouml;&szlig;e',
+    'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
     'Sleep'                => 'Schlaf',
     'SortAsc'              => 'aufsteigend',
     'SortBy'               => 'Sortieren nach',
@@ -693,6 +696,7 @@ $CLANG = array(
     'MonitorCount'         => '%1$s %2$s', // For example '4 Monitors' (from Vlang below)
     'MonitorFunction'      => 'Monitor %1$s Funktion',
     'RunningRecentVer'     => 'Sie benutzen die aktuellste Version von Zoneminder, v%s.',
+    'VersionMismatch'      => 'Version mismatch, system is version %1$s, database is %2$s.', // Added - 2011-05-25
 );
 
 // The next section allows you to describe a series of word ending and counts used to 
