@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web UK English language file, $Date: 2009-03-31 14:00:49 +0100 (Tue, 31 Mar 2009) $, $Revision: 2829 $
+// ZoneMinder web UK English language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -128,7 +128,7 @@ $SLANG = array(
     'BadChannel'            => 'Channel must be set to an integer of zero or more',
     'BadDevice'             => 'Device must be set to a valid value',
     'BadFormat'             => 'Format must be set to a valid value',
-    'BadFPSReportInterval'  => 'FPS report interval buffer count must be an integer of 100 or more',
+    'BadFPSReportInterval'  => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFrameSkip'          => 'Frame skip count must be an integer of zero or more',
     'BadHeight'             => 'Height must be set to a valid value',
     'BadHost'               => 'Host must be set to a valid ip address or hostname, do not include http://',
@@ -247,6 +247,7 @@ $SLANG = array(
     'Dimensions'            => 'Dimensions',
     'DisableAlarms'         => 'Disable Alarms',
     'Disk'                  => 'Disk',
+    'Display'               => 'Display',
     'DonateAlready'         => 'No, I\'ve already donated',
     'DonateEnticement'      => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br/><br/>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br/><br/>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
     'Donate'                => 'Please Donate',
@@ -547,6 +548,7 @@ $SLANG = array(
     'Rewind'                => 'Rewind',
     'RotateLeft'            => 'Rotate Left',
     'RotateRight'           => 'Rotate Right',
+    'RunLocalUpdate'        => 'Please run zmupdate.pl to update',
     'RunMode'               => 'Run Mode',
     'Running'               => 'Running',
     'RunState'              => 'Run State',
@@ -568,6 +570,7 @@ $SLANG = array(
     'ShowTimeline'          => 'Show Timeline',
     'SignalCheckColour'     => 'Signal Check Colour',
     'Size'                  => 'Size',
+    'SkinDescription'       => 'Change the default skin for this computer',
     'Sleep'                 => 'Sleep',
     'SortAsc'               => 'Asc',
     'SortBy'                => 'Sort by',
@@ -693,6 +696,7 @@ $CLANG = array(
     'MonitorCount'          => '%1$s %2$s', // For example '4 Monitors' (from Vlang below)
     'MonitorFunction'       => 'Monitor %1$s Function',
     'RunningRecentVer'      => 'You are running the most recent version of ZoneMinder, v%s.',
+    'VersionMismatch'       => 'Version mismatch, system is version %1$s, database is %2$s.',
 );
 
 // The next section allows you to describe a series of word ending and counts used to 
