@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Argentinian Spanish language file, $Date: 2009-02-08 17:39:12 +0000 (Sun, 08 Feb 2009) $, $Revision: 2746 $
+// ZoneMinder web Argentinian Spanish language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -70,6 +70,7 @@ $SLANG = array(
     'AttrWeekday'          => 'Da Semana',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
+    'Available'            => 'Available',              // Added - 2009-03-31
     'AvgBrScore'           => 'Punt.<br/>Promedio',
     'Background'           => 'Background',
     'BackgroundFilter'     => 'Run filter in background',
@@ -77,7 +78,7 @@ $SLANG = array(
     'BadAlarmMaxFPS'       => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'           => 'Channel must be set to an integer of zero or more',
     'BadDevice'            => 'Device must be set to a valid value',
-    'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 100 or more',
+    'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
     'BadFrameSkip'         => 'Frame skip count must be an integer of zero or more',
     'BadHeight'            => 'Height must be set to a valid value',
@@ -87,6 +88,7 @@ $SLANG = array(
     'BadLabelY'            => 'Label Y co-ordinate must be set to an integer of zero or more',
     'BadMaxFPS'            => 'Maximum FPS must be a positive integer or floating point value',
     'BadNameChars'         => 'Los nombres pueden contener solamente caracteres alfanumricos ms el guin y la raya',
+    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Path must be set to a valid value',
     'BadPort'              => 'Port must be set to a valid number',
     'BadPostEventCount'    => 'Post event image count must be an integer of zero or more',
@@ -150,6 +152,7 @@ $SLANG = array(
     'CaptureWidth'         => 'Captura Ancho',
     'Cause'                => 'Cause',
     'CheckMethod'          => 'Alarm Check Method',
+    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Elegir Filtro',
     'ChoosePreset'         => 'Choose Preset',
     'Close'                => 'Cerrar',
@@ -184,6 +187,7 @@ $SLANG = array(
     'DeleteAndPrev'        => 'Borrar &amp; Anterior',
     'DeleteSavedFilter'    => 'Borrar Filtro Guardado',
     'Description'          => 'Descripcin',
+    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
     'DeviceChannel'        => 'Canal',
     'DeviceFormat'         => 'Seal',
@@ -193,6 +197,7 @@ $SLANG = array(
     'Dimensions'           => 'Dimensiones',
     'DisableAlarms'        => 'Disable Alarms',
     'Disk'                 => 'Disco',
+    'Display'              => 'Display',                // Added - 2011-01-30
     'Donate'               => 'Please Donate',
     'DonateAlready'        => 'No, I\'ve already donated',
     'DonateEnticement'     => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
@@ -203,6 +208,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
     'Download'             => 'Download',
+    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Duracin',
     'Edit'                 => 'Editar',
     'Email'                => 'Email',
@@ -385,6 +391,8 @@ $SLANG = array(
     'MonitorIds'           => 'Ids&nbsp;Monitor',
     'MonitorPreset'        => 'Monitor Preset',
     'MonitorPresetIntro'   => 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>',
+    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Monitores',
     'Montage'              => 'Cmara Mltiple',
     'Month'                => 'Mes',
@@ -405,6 +413,7 @@ $SLANG = array(
     'NewUser'              => 'Nuevo Usuario',
     'Next'                 => 'Siguiente',
     'No'                   => 'No',
+    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
     'NoFramesRecorded'     => 'No hay movimientos grabados para este evento',
     'NoGroup'              => 'No Group',
     'NoSavedFilters'       => 'FiltrosNoGuardados',
@@ -459,6 +468,7 @@ $SLANG = array(
     'Preset'               => 'Preset',
     'Presets'              => 'Presets',
     'Prev'                 => 'Prev',
+    'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protocol',
     'Rate'                 => 'Ritmo',
     'Real'                 => 'Real',
@@ -489,6 +499,7 @@ $SLANG = array(
     'Rewind'               => 'Rewind',
     'RotateLeft'           => 'Rotar a la derecha',
     'RotateRight'          => 'Rotar a la izquierda',
+    'RunLocalUpdate'       => 'Please run zmupdate.pl to update', // Added - 2011-05-25
     'RunMode'              => 'Metodo Ejecucion',
     'RunState'             => 'Estado de Ejecucin',
     'Running'              => 'Ejecutando',
@@ -510,6 +521,7 @@ $SLANG = array(
     'ShowTimeline'         => 'Show Timeline',
     'SignalCheckColour'    => 'Signal Check Colour',
     'Size'                 => 'Size',
+    'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
     'Sleep'                => 'Sleep',
     'SortAsc'              => 'Asc',
     'SortBy'               => 'Ordenar por',
@@ -635,6 +647,7 @@ $CLANG = array(
     'MonitorCount'         => '%1$s %2$s',
     'MonitorFunction'      => 'Monitor %1$s Funcion',
     'RunningRecentVer'     => 'You are running the most recent version of Zoneminder, v%s.',
+    'VersionMismatch'      => 'Version mismatch, system is version %1$s, database is %2$s.', // Added - 2011-05-25
 );
 
 // Variable arrays expressing plurality, see the zmVlang description above
@@ -660,4 +673,3 @@ $OLANG = array(
 );
 
 ?>
-
