@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web HU Hungarian language file, $Date: 2009-06-29 10:52:48 +0100 (Mon, 29 Jun 2009) $, $Revision: 2934 $
+// ZoneMinder web HU Hungarian language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -136,7 +136,7 @@ $SLANG = array(
     'BadAlarmMaxFPS'       => 'A riad maximlis FPS szma pozitv szm legyen',
     'BadChannel'           => 'A csatorna szma 0 vagy nagyobb egsz szm legyen',
     'BadDevice'            => 'Az eszkz rtk vals legyen',
-    'BadFPSReportInterval' => 'FPS informcis idkz puffer szmllja 100 vagy nagyobb egsz legyen',
+    'BadFPSReportInterval' => 'FPS informcis idkz puffer szmllja 0 vagy nagyobb egsz legyen',
     'BadFormat'            => 'A tpus 0 vagy nagyobb egsz szm legyen',
     'BadFrameSkip'         => 'Kpkocka eldobsok szma 0 vagy nagyobb egsz szm legyen',
     'BadHeight'            => 'A kpmagassg rvnyes rtk legyen kppontban',
@@ -255,6 +255,7 @@ $SLANG = array(
     'Dimensions'           => 'Dimenzik',
     'DisableAlarms'        => 'Riaszts tiltsa',
     'Disk'                 => 'Trhely',
+    'Display'               => 'Megjelens',
     'Donate'               => 'Krem tmogasson',
     'DonateAlready'        => 'Nem, n mr tmogattam',
     'DonateEnticement'     => 'n mr j ideje hasznlja a ZoneMindert remlhetleg hasznos kiegsztsnek tartja hza vagy munkahelye biztostsban. Br ZoneMinder szabad, nylt forrskd, s az is marad; a fejlesztse pnzbe kerl. Ha tmogatni szeretn a jvbeni fejlesztseket s az j funkcikat krem tmogasson. A tmogats teljesen nkntes, de nagyon megbecslt s annyival tud tmogatni amennyivel kvn.<br><br>Ha tmogatni szertne krem vlasszon az albbi lehetsgekbl vagy ltogassa meg a http://www.zoneminder.com/donate.html oldalt.<br><br>Ksznm, hogy hasznlja a ZoneMinder-t s ne felejtse el megltogatni a frumokat a ZoneMinder.com oldalon tmogatsrt s tletekrt, hogy tudja mg jobban hasznlni a ZoneMinder-t.',
@@ -556,6 +557,7 @@ $SLANG = array(
     'Rewind'               => 'Visszatekers',
     'RotateLeft'           => 'Balra forgats',
     'RotateRight'          => 'Jobbra forgats',
+    'RunLocalUpdate'       => 'Please run zmupdate.pl to update', // Added - 2011-05-25
     'RunMode'              => 'Futsi md',
     'RunState'             => 'A ZoneMinder llapota',
     'Running'              => 'les',
@@ -577,6 +579,7 @@ $SLANG = array(
     'ShowTimeline'         => 'Idvonal megjelents',
     'SignalCheckColour'    => 'Szn a jel kimaradsakor',
     'Size'                 => 'Fjlmret',
+    'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
     'Sleep'                => 'Alvs',
     'SortAsc'              => 'Nvekv',
     'SortBy'               => 'Sorbarendezs:',
@@ -702,6 +705,7 @@ $CLANG = array(
     'MonitorCount'         => '%1$s %2$s', // For example '4 Monitors' (from Vlang below)
     'MonitorFunction'      => 'Megfigyels funkci: %1$s',
     'RunningRecentVer'     => 'A legfrissebb ZoneMinder verzit hasznlod, v%s.',
+    'VersionMismatch'      => 'Version mismatch, system is version %1$s, database is %2$s.', // Added - 2011-05-25
 );
 
 // The next section allows you to describe a series of word ending and counts used to 
