@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Italian language file, $Date: 2009-05-24 11:00:20 +0100 (Sun, 24 May 2009) $, $Revision: 2889 $
+// ZoneMinder web Italian language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -124,7 +124,7 @@ $SLANG = array(
     'AttrWeekday'          => 'Giorno della settimana',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
-    'Available'            => 'Available',              // Added - 2009-03-31
+    'Available'            => 'Disponibile',              // Added - 2009-03-31
     'AvgBrScore'           => 'Punteggio<br/>medio',
     'Background'           => 'Background',
     'BackgroundFilter'     => 'Esegui filtro in background',
@@ -132,7 +132,7 @@ $SLANG = array(
     'BadAlarmMaxFPS'       => 'Il numero massimo di FPS dell\'allarme deve essere un numero intero positivo o un valore in virgola mobile',
     'BadChannel'           => 'Il canale deve essere settato con un numero intero uguale o maggiore di zero',
     'BadDevice'            => 'Il dispositivo deve essere impostato con un valore valido',
-    'BadFPSReportInterval' => 'L\'intervallo di FPS per i report deve essere un numero intero superiore a 100',
+    'BadFPSReportInterval' => 'L\'intervallo di FPS per i report deve essere un numero intero superiore a 0',
     'BadFormat'            => 'Il formato deve essere impostato con un numero intero come 0 o maggiore',
     'BadFrameSkip'         => 'Il numero di Frame da scartare deve essere un intero uguale a 0 o superiore',
     'BadHeight'            => 'L\'altezza deve essere impostata con un valore valido',
@@ -142,7 +142,7 @@ $SLANG = array(
     'BadLabelY'            => 'L\'etichetta della coordinata Y deve essere un numero intero pari a 0 o maggiore',
     'BadMaxFPS'            => 'I frame per secondo (FPS) massimi devono essere un numero intero positivo o un valore in virgola mobile',
     'BadNameChars'         => 'I nomi possono contenere solo caratteri alfanumerici pi&ugrave; i caratteri - e _',
-    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
+    'BadPalette'           => 'La palette dei colori deve essere impostata ad un valore valido', // Added - 2009-03-31
     'BadPath'              => 'Il percorso deve essere impostato con un valore valido',
     'BadPort'              => 'La porta deve essere settata con un valore valido',
     'BadPostEventCount'    => 'Il buffer d\'immagine successivo ad un evento deve essere un numero maggiore o uguale a zero',
@@ -201,12 +201,12 @@ $SLANG = array(
     'Cancel'               => 'Annulla',
     'CancelForcedAlarm'    => 'Annulla Allarme Forzato',
     'CaptureHeight'        => 'Altezza img catturata',
-    'CaptureMethod'        => 'Capture Method',         // Added - 2009-02-08
+    'CaptureMethod'        => 'Metodo di cattura',         // Added - 2009-02-08
     'CapturePalette'       => 'Paletta img Catturata',
     'CaptureWidth'         => 'Larghezza img Catturata',
     'Cause'                => 'Causa',
     'CheckMethod'          => 'Metodo di Controllo Allarme',
-    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
+    'ChooseDetectedCamera' => 'Scegli telecamera rilevata', // Added - 2009-03-31
     'ChooseFilter'         => 'Scegli Filtro',
     'ChoosePreset'         => 'Scegli Preset',
     'Close'                => 'Chiudi',
@@ -241,8 +241,8 @@ $SLANG = array(
     'DeleteAndPrev'        => 'Elimina &amp; Precedente',
     'DeleteSavedFilter'    => 'Elimina il filtro salvato',
     'Description'          => 'Descrizione',
-    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
-    'Device'               => 'Device',                 // Added - 2009-02-08
+    'DetectedCameras'      => 'Telecamere Rilevate',       // Added - 2009-03-31
+    'Device'               => 'Periferica',                 // Added - 2009-02-08
     'DeviceChannel'        => 'Canale Periferica',
     'DeviceFormat'         => 'Formato',
     'DeviceNumber'         => 'Numero Periferica',
@@ -251,6 +251,7 @@ $SLANG = array(
     'Dimensions'           => 'Dimensioni',
     'DisableAlarms'        => 'Disabil Allarme',
     'Disk'                 => 'Utilizzo Disco',
+    'Display'              => 'Display',                // Added - 2011-01-30
     'Donate'               => 'Donate,per favore',
     'DonateAlready'        => 'No, ho gia donato...    ',
     'DonateEnticement'     => 'Stai usando ZoneMinder da un po\' di tempo e spero che tu lo stia trovando utile per la sicurezza di casa tua o del tuo posto di lavoro..Anche se ZoneMinder e\' distribuito liberamente come software libero,costa soldi sia svilupparlo che supportarlo. Se preferisci che questo software continui ad avere supporto e sviluppo in futuro allora considera l\idea di fare una piccola donazione. Donare e\' ovviamente opzionale, ma apprezzato e puoi donare quanto vuoi,quel poco o tanto che tu desideri.<br><br>Se hai voglia per cortesia seleziona l\'opzione sotto o punta il tuo browser a http://www.zoneminder.com/donate.html .<br><br>Grazie per usare ZoneMinder e non dimenticare di visitare il forum in ZoneMinder.com se cerchi supporto o hai suggerimenti riguardo a come rendere migliore Zoneminder.',
@@ -261,7 +262,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Non ancora, ricordamelo ancora tra 1 settimana',
     'DonateYes'            => 'Si,mi piacerebbe donare qualcosa ora',
     'Download'             => 'Download',
-    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
+    'DuplicateMonitorName' => 'Il nome del monitor e\' gia\' presente', // Added - 2009-03-31
     'Duration'             => 'Durata',
     'Edit'                 => 'Modifica',
     'Email'                => 'Email',
@@ -290,7 +291,7 @@ $SLANG = array(
     'ExportImageFiles'     => 'Esporta le immagini',
     'ExportMiscFiles'      => 'Esporto Altri file (se presenti)',
     'ExportOptions'        => 'Opzioni Esportazione',
-    'ExportSucceeded'      => 'Export Succeeded',       // Added - 2009-02-08
+    'ExportSucceeded'      => 'Export completata con successo',       // Added - 2009-02-08
     'ExportVideoFiles'     => 'Esporto File Video (se presenti)',
     'Exporting'            => 'In corso.',
     'FPS'                  => 'fps',
@@ -429,7 +430,7 @@ $SLANG = array(
     'MinPanSpeed'          => 'Velocita\' minima del Pan',
     'MinPanStep'           => 'Step minimo del Pan',
     'MinPixelThresLtMax'   => 'I pixel minimi della soglia devono essere minori dei pixel massimi della soglia',
-    'MinPixelThresUnset'   => 'You must specify a minimum pixel threshold', // Added - 2009-02-08
+    'MinPixelThresUnset'   => 'Devi specificare una soglia minima di pixel', // Added - 2009-02-08
     'MinTiltRange'         => 'Range minimo del Tilt',
     'MinTiltSpeed'         => 'Velocita\' minima del Tilt',
     'MinTiltStep'          => 'Step minimo del Tilt',
@@ -443,7 +444,7 @@ $SLANG = array(
     'Monitor'              => 'Monitor',
     'MonitorIds'           => 'Monitor&nbsp;Ids',
     'MonitorPreset'        => 'Monitor Presenti',
-    'MonitorPresetIntro'   => 'Selezionare un appropriato pre settaggio dalla lista riportata qui sotto.<br><br>Per favore notare che questo potrebbe sovrascrivere ogni valore che hai già configurato su questo monitor.<br><br>',
+    'MonitorPresetIntro'   => 'Selezionare un appropriato pre settaggio dalla lista riportata qui sotto.<br><br>Per favore notare che questo potrebbe sovrascrivere ogni valore che hai gi&agrave;  configurato su questo monitor.<br><br>',
     'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
     'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Monitors',
@@ -466,9 +467,9 @@ $SLANG = array(
     'NewUser'              => 'Nuovo Utente',
     'Next'                 => 'Prossimo',
     'No'                   => 'No',
-    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
+    'NoDetectedCameras'    => 'Nessuna telecamera rilevata',    // Added - 2009-03-31
     'NoFramesRecorded'     => 'Non ci sono immagini salvate per questo evento',
-    'NoGroup'              => 'No Group',               // Added - 2009-02-08
+    'NoGroup'              => 'Nessun gruppo',               // Added - 2009-02-08
     'NoSavedFilters'       => 'NessunFiltroSalvato',
     'NoStatisticsRecorded' => 'Non ci sono statistiche salvate per questo evento/immagine',
     'None'                 => 'Nessuno',
@@ -521,7 +522,7 @@ $SLANG = array(
     'Preset'               => 'Preset',
     'Presets'              => 'Presets',
     'Prev'                 => 'Prec',
-    'Probe'                => 'Probe',                  // Added - 2009-03-31
+    'Probe'                => 'Prova la telecamera',                  // Added - 2009-03-31
     'Protocol'             => 'Protocol',
     'Rate'                 => 'Velocita\'',
     'Real'                 => 'Reale',
@@ -534,8 +535,8 @@ $SLANG = array(
     'RemoteHostPort'       => 'Porta dell\'Host Remoto',
     'RemoteHostSubPath'    => 'Remote Host SubPath',    // Added - 2009-02-08
     'RemoteImageColours'   => 'Colori delle immagini Remote',
-    'RemoteMethod'         => 'Remote Method',          // Added - 2009-02-08
-    'RemoteProtocol'       => 'Remote Protocol',        // Added - 2009-02-08
+    'RemoteMethod'         => 'Metodo Remoto',          // Added - 2009-02-08
+    'RemoteProtocol'       => 'Protocollo Remoto',        // Added - 2009-02-08
     'Rename'               => 'Rinomina',
     'Replay'               => 'Replay',
     'ReplayAll'            => 'All Events',
@@ -552,9 +553,10 @@ $SLANG = array(
     'Rewind'               => 'Riavvolgi',
     'RotateLeft'           => 'Ruota a Sinista',
     'RotateRight'          => 'Ruota a Destra',
-    'RunMode'              => 'Modalita funzionamento',
-    'RunState'             => 'Stato Avviato',
-    'Running'              => 'Avviato',
+    'RunLocalUpdate'       => 'Please run zmupdate.pl to update', // Added - 2011-05-25
+    'RunMode'              => 'Modalita\' funzionamento',
+    'RunState'             => 'Stato di funzionamento',
+    'Running'              => 'Attivo',
     'Save'                 => 'Salva',
     'SaveAs'               => 'Salva come',
     'SaveFilter'           => 'salva Filtro',
@@ -573,13 +575,14 @@ $SLANG = array(
     'ShowTimeline'         => 'Mostra linea temporale',
     'SignalCheckColour'    => 'Signal Check Colour',
     'Size'                 => 'grandezza',
+    'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
     'Sleep'                => 'Sleep',
     'SortAsc'              => 'Cresc',
     'SortBy'               => 'Ordina per',
     'SortDesc'             => 'Decr',
     'Source'               => 'Sorgente',
-    'SourceColours'        => 'Source Colours',         // Added - 2009-02-08
-    'SourcePath'           => 'Source Path',            // Added - 2009-02-08
+    'SourceColours'        => 'Colori della Sorgente',         // Added - 2009-02-08
+    'SourcePath'           => 'Percorso della Sorgente',            // Added - 2009-02-08
     'SourceType'           => 'Tipo Sorgente',
     'Speed'                => 'Velocita\'',
     'SpeedHigh'            => 'Alta Velocita\'',
@@ -599,7 +602,7 @@ $SLANG = array(
     'StepSmall'            => 'Piccolo passo',
     'Stills'               => 'Foto',
     'Stop'                 => 'Stop',
-    'Stopped'              => 'Fermo-immagine',
+    'Stopped'              => 'Inattivo',
     'Stream'               => 'Flusso',
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Accetta',
@@ -625,7 +628,7 @@ $SLANG = array(
     'TurboTiltSpeed'       => 'Velocita\' Turbo Tilt',
     'Type'                 => 'Tipo',
     'Unarchive'            => 'Togli dall\'archivio',
-    'Undefined'            => 'Undefined',              // Added - 2009-02-08
+    'Undefined'            => 'Non specificato',              // Added - 2009-02-08
     'Units'                => 'Unit&agrave;',
     'Unknown'              => 'Sconosciuto',
     'Update'               => 'Aggiorna',
@@ -698,6 +701,7 @@ $CLANG = array(
     'MonitorCount'         => '%1$s %2$s', // For example '4 Monitors' (from Vlang below)
     'MonitorFunction'      => 'Funzione Monitor %1$s',
     'RunningRecentVer'     => 'Stai usando la versione pi&ugrave; aggiornata di ZoneMinder, v%s.',
+    'VersionMismatch'      => 'Version mismatch, system is version %1$s, database is %2$s.', // Added - 2011-05-25
 );
 
 // The next section allows you to describe a series of word ending and counts used to 
