@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Japanese language file, $Date: 2009-02-08 17:39:12 +0000 (Sun, 08 Feb 2009) $, $Revision: 2746 $
+// ZoneMinder web Japanese language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -119,6 +119,7 @@ $SLANG = array(
     'AttrWeekday'          => 'j',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
+    'Available'            => 'Available',              // Added - 2009-03-31
     'AvgBrScore'           => '<br/>',
     'Background'           => 'Background',
     'BackgroundFilter'     => 'Run filter in background',
@@ -126,7 +127,7 @@ $SLANG = array(
     'BadAlarmMaxFPS'       => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'           => 'Channel must be set to an integer of zero or more',
     'BadDevice'            => 'Device must be set to a valid value',
-    'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 100 or more',
+    'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
     'BadFrameSkip'         => 'Frame skip count must be an integer of zero or more',
     'BadHeight'            => 'Height must be set to a valid value',
@@ -136,6 +137,7 @@ $SLANG = array(
     'BadLabelY'            => 'Label Y co-ordinate must be set to an integer of zero or more',
     'BadMaxFPS'            => 'Maximum FPS must be a positive integer or floating point value',
     'BadNameChars'         => 'Names may only contain alphanumeric characters plus hyphen and underscore',
+    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Path must be set to a valid value',
     'BadPort'              => 'Port must be set to a valid number',
     'BadPostEventCount'    => 'Post event image count must be an integer of zero or more',
@@ -199,6 +201,7 @@ $SLANG = array(
     'CaptureWidth'         => '荞ݕ',
     'Cause'                => 'Cause',
     'CheckMethod'          => 'װ @',
+    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => '̨̑I',
     'ChoosePreset'         => 'Choose Preset',
     'Close'                => '',
@@ -233,6 +236,7 @@ $SLANG = array(
     'DeleteAndPrev'        => 'O폜',
     'DeleteSavedFilter'    => 'ۑ̨̍폜',
     'Description'          => '',
+    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
     'DeviceChannel'        => '޲ ',
     'DeviceFormat'         => '޲ ̫ϯ',
@@ -242,6 +246,7 @@ $SLANG = array(
     'Dimensions'           => '@',
     'DisableAlarms'        => 'Disable Alarms',
     'Disk'                 => 'Disk',
+    'Display'              => 'Display',                // Added - 2011-01-30
     'Donate'               => 'Please Donate',
     'DonateAlready'        => 'No, I\'ve already donated',
     'DonateEnticement'     => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
@@ -252,6 +257,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
     'Download'             => 'Download',
+    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'p',
     'Edit'                 => 'ҏW',
     'Email'                => 'Ұ',
@@ -434,6 +440,8 @@ $SLANG = array(
     'MonitorIds'           => ' ID',
     'MonitorPreset'        => 'Monitor Preset',
     'MonitorPresetIntro'   => 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>',
+    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => '',
     'Montage'              => 'ޭ',
     'Month'                => '',
@@ -454,6 +462,7 @@ $SLANG = array(
     'NewUser'              => 'Vհ',
     'Next'                 => '',
     'No'                   => '',
+    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
     'NoFramesRecorded'     => '̲Ăڰт͓o^Ă܂',
     'NoGroup'              => 'No Group',
     'NoSavedFilters'       => 'ۑꂽ̨͂܂',
@@ -508,6 +517,7 @@ $SLANG = array(
     'Preset'               => 'Preset',
     'Presets'              => 'Presets',
     'Prev'                 => 'O',
+    'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protocol',
     'Rate'                 => 'ڰ',
     'Real'                 => 'p',
@@ -538,6 +548,7 @@ $SLANG = array(
     'Rewind'               => 'Rewind',
     'RotateLeft'           => 'ɉ]',
     'RotateRight'          => 'Eɉ]',
+    'RunLocalUpdate'       => 'Please run zmupdate.pl to update', // Added - 2011-05-25
     'RunMode'              => 'NӰ',
     'RunState'             => 'N',
     'Running'              => 'N',
@@ -559,6 +570,7 @@ $SLANG = array(
     'ShowTimeline'         => 'Show Timeline',
     'SignalCheckColour'    => 'Signal Check Colour',
     'Size'                 => 'Size',
+    'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
     'Sleep'                => 'Sleep',
     'SortAsc'              => 'Asc',
     'SortBy'               => 'Sort by',
@@ -684,6 +696,7 @@ $CLANG = array(
     'MonitorCount'         => '%1$s %2$s',
     'MonitorFunction'      => '%1$s @\\',
     'RunningRecentVer'     => 'ȂZoneMinder̍ŐVްޮ v%s.gĂ܂',
+    'VersionMismatch'      => 'Version mismatch, system is version %1$s, database is %2$s.', // Added - 2011-05-25
 );
 
 // The next section allows you to describe a series of word ending and counts used to 
@@ -807,4 +820,3 @@ $OLANG = array(
 );
 
 ?>
-
