@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Polish language file, $Date: 2009-05-13 11:58:00 +0100 (Wed, 13 May 2009) $, $Revision: 2872 $
+// ZoneMinder web Polish language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -127,7 +127,7 @@ $SLANG = array(
     'BadAlarmMaxFPS'       => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'           => 'Channel must be set to an integer of zero or more',
     'BadDevice'            => 'Device must be set to a valid value',
-    'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 100 or more',
+    'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
     'BadFrameSkip'         => 'Frame skip count must be an integer of zero or more',
     'BadHeight'            => 'Height must be set to a valid value',
@@ -246,6 +246,7 @@ $SLANG = array(
     'Dimensions'           => 'Rozmiary',
     'DisableAlarms'        => 'Disable Alarms',
     'Disk'                 => 'Dysk',
+    'Display'              => 'Display',                // Added - 2011-01-30
     'Donate'               => 'Please Donate',
     'DonateAlready'        => 'No, I\'ve already donated',
     'DonateEnticement'     => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
@@ -547,6 +548,7 @@ $SLANG = array(
     'Rewind'               => 'Rewind',
     'RotateLeft'           => 'Obr w lewo',
     'RotateRight'          => 'Obr w prawo',
+    'RunLocalUpdate'       => 'Please run zmupdate.pl to update', // Added - 2011-05-25
     'RunMode'              => 'Tryb pracy',
     'RunState'             => 'Stan pracy',
     'Running'              => 'Pracuje',
@@ -568,6 +570,7 @@ $SLANG = array(
     'ShowTimeline'         => 'Show Timeline',
     'SignalCheckColour'    => 'Signal Check Colour',
     'Size'                 => 'Size',
+    'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
     'Sleep'                => 'Sleep',
     'SortAsc'              => 'Nara.',
     'SortBy'               => 'Sortuj',
@@ -693,6 +696,7 @@ $CLANG = array(
     'MonitorCount'         => '%1$s %2$s',
     'MonitorFunction'      => 'Monitor %1$s Funkcja',
     'RunningRecentVer'     => 'Uruchomie najnowsz wersj ZoneMinder, v%s.',
+    'VersionMismatch'      => 'Version mismatch, system is version %1$s, database is %2$s.', // Added - 2011-05-25
 );
 
 // The next section allows you to describe a series of word ending and counts used to
