@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Swedish language file, $Date: 2009-05-24 11:00:20 +0100 (Sun, 24 May 2009) $, $Revision: 2889 $
+// ZoneMinder web Swedish language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -128,7 +128,7 @@ $SLANG = array(
     'BadAlarmMaxFPS'       => 'Larm fr bilder/s mste vara ett positivt heltal eller ett flyttal',
     'BadChannel'           => 'Kanalen mste vara ett heltal, noll eller hgre',
     'BadDevice'            => 'Enheten mste sttas till ett giltigt vrde',
-    'BadFPSReportInterval' => 'Buffern fr ramintervallrapporten mste vara ett heltal p minst 100 eller hgre',
+    'BadFPSReportInterval' => 'Buffern fr ramintervallrapporten mste vara ett heltal p minst 0 eller hgre',
     'BadFormat'            => 'Formatet mste vara ett heltal, noll eller hgre',
     'BadFrameSkip'         => 'Vrdet fr ramverhopp mste vara ett heltal p 0 eller hgre',
     'BadHeight'            => 'Hjden mste sttas till ett giltigt vrde',
@@ -247,6 +247,7 @@ $SLANG = array(
     'Dimensions'           => 'Dimensioner',
     'DisableAlarms'        => 'Avaktivera larm',
     'Disk'                 => 'Disk',
+    'Display'              => 'Display',                // Added - 2011-01-30
     'Donate'               => 'Var vnlig och donera',
     'DonateAlready'        => 'Nej, Jag har redan donerat',
     'DonateEnticement'     => 'Du har krt ZoneMinder ett tag nu och frhoppningsvis har du sett att det fungerar bra hemma eller p ditt fretag. ven om ZoneMinder r, och kommer att vara, fri programvara och ppen kallkod, s kostar det pengar att utveckla och underhlla. Om du vill hjlpa till med framtida utveckling och nya funktioner s var vanlig och bidrag med en slant. Bidragen r naturligtvis en option men mycket uppskattade och du kan bidra med precis hur mycket du vill.<br><br>Om du vill ge ett bidrag vljer du nedan eller surfar till http://www.zoneminder.com/donate.html.<br><br>Tack fr att du anvnder ZoneMinder, glm inte att beska forumen p ZoneMinder.com fr support och frslag om hur du fr din ZoneMinder att fungera lite bttre.',
@@ -548,6 +549,7 @@ $SLANG = array(
     'Rewind'               => 'Backa',
     'RotateLeft'           => 'Rotera vnster',
     'RotateRight'          => 'Rotera hger',
+    'RunLocalUpdate'       => 'Please run zmupdate.pl to update', // Added - 2011-05-25
     'RunMode'              => 'Krlge',
     'RunState'             => 'Krlge',
     'Running'              => 'Krs',
@@ -569,6 +571,7 @@ $SLANG = array(
     'ShowTimeline'         => 'Visa tidslinje',
     'SignalCheckColour'    => 'Signal Check Colour',
     'Size'                 => 'Storlek',
+    'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
     'Sleep'                => 'Vila',
     'SortAsc'              => 'Stigande',
     'SortBy'               => 'Sortera',
@@ -694,6 +697,7 @@ $CLANG = array(
     'MonitorCount'         => '%1$s %2$s', // For example '4 Monitors' (from Vlang below)
     'MonitorFunction'      => 'Bevakare %1$s funktion',
     'RunningRecentVer'     => 'Du anvnder den senaste versionen av ZoneMinder, v%s.',
+    'VersionMismatch'      => 'Version mismatch, system is version %1$s, database is %2$s.', // Added - 2011-05-25
 );
 
 // The next section allows you to describe a series of word ending and counts used to 
