@@ -52,24 +52,30 @@ function xhtmlHeaders( $file, $title )
     {
 ?>
   <style type="text/css">
+  /*<![CDATA[*/
 <?php
         require_once( $viewCssPhpFile );
 ?>
+  /*]]>*/
   </style>
 <?php
     }
 ?>
-  <script type="text/javascript" src="tools/mootools/mootools-1.2.1-core-nc.js"></script>
-  <script type="text/javascript" src="tools/mootools/mootools-1.2-more-nc.js"></script>
+  <script type="text/javascript" src="tools/mootools/mootools-core.js"></script>
+  <script type="text/javascript" src="tools/mootools/mootools-more.js"></script>
   <script type="text/javascript" src="js/mootools.ext.js"></script>
 <?php
     if ( $skinJsPhpFile )
     {
 ?>
   <script type="text/javascript">
+  //<![CDATA[
+  <!--
 <?php
     require_once( $skinJsPhpFile );
 ?>
+  //-->
+  //]]>
   </script>
 <?php
     }
@@ -77,9 +83,13 @@ function xhtmlHeaders( $file, $title )
     {
 ?>
   <script type="text/javascript">
+  //<![CDATA[
+  <!--
 <?php
         require_once( $viewJsPhpFile );
 ?>
+  //-->
+  //]]>
   </script>
 <?php
     }
