@@ -6,23 +6,25 @@ function setButtonState( element, butClass )
 
 function changeScale()
 {
-    var scale = $('scale').getValue();
-    var baseWidth = event.Width;
-    var baseHeight = event.Height;
+    var scale = $('scale').get('value');
+    var baseWidth = eventData.Width;
+    var baseHeight = eventData.Height;
     var newWidth = ( baseWidth * scale ) / SCALE_BASE;
     var newHeight = ( baseHeight * scale ) / SCALE_BASE;
 
     streamScale( scale );
 
-    var streamImg = $('imageFeed').getElement('img');
-    $(streamImg).setStyles( { 'width': newWidth, 'height': newHeight } );
+    /*Stream could be an applet so can't use moo tools*/ 
+    var streamImg = document.getElementById('evtStream');
+    streamImg.style.width = newWidth + "px";
+    streamImg.style.height = newHeight + "px";
 }
 
 function changeReplayMode()
 {
-    var replayMode = $('replayMode').getValue();
+    var replayMode = $('replayMode').get('value');
 
-    Cookie.set( 'replayMode', replayMode, { duration: 10*365 })
+    Cookie.write( 'replayMode', replayMode, { duration: 10*365 })
 
     refreshWindow();
 }
@@ -33,15 +35,15 @@ var streamCmdTimer = null;
 var streamStatus = null;
 var lastEventId = 0;
 
-function getCmdResponse( respText )
+function getCmdResponse( respObj, respText )
 {
+    if ( checkStreamForErrors( "getCmdResponse" ,respObj ) )
+        return;
+
     if ( streamCmdTimer )
         streamCmdTimer = $clear( streamCmdTimer );
 
-    if ( !respText )
-        return;
-    var response = Json.evaluate( respText );
-    streamStatus = response.status;
+    streamStatus = respObj.status;
 
     var eventId = streamStatus.event;
     if ( eventId != lastEventId )
@@ -51,19 +53,19 @@ function getCmdResponse( respText )
     }
     if ( streamStatus.paused == true )
     {
-        $('modeValue').setHTML( "Paused" );
+        $('modeValue').set( 'text', "Paused" );
         $('rate').addClass( 'hidden' );
         streamPause( false );
     }
     else 
     {
-        $('modeValue').setHTML( "Replay" );
-        $('rateValue').setHTML( streamStatus.rate );
+        $('modeValue').set( 'text', "Replay" );
+        $('rateValue').set( 'text', streamStatus.rate );
         $('rate').removeClass( 'hidden' );
         streamPlay( false );
     }
-    $('progressValue').setHTML( secsToTime( parseInt(streamStatus.progress) ) );
-    $('zoomValue').setHTML( streamStatus.zoom );
+    $('progressValue').set( 'text', secsToTime( parseInt(streamStatus.progress) ) );
+    $('zoomValue').set( 'text', streamStatus.zoom );
     if ( streamStatus.zoom == "1.0" )
         setButtonState( $('zoomOutBtn'), 'unavail' );
     else
@@ -74,6 +76,8 @@ function getCmdResponse( respText )
     streamCmdTimer = streamQuery.delay( streamTimeout );
 }
 
+var streamReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, link: 'chain', onSuccess: getCmdResponse } );
+
 function streamPause( action )
 {
     setButtonState( $('pauseBtn'), 'active' );
@@ -83,24 +87,21 @@ function streamPause( action )
     setButtonState( $('slowRevBtn'), 'inactive' );
     setButtonState( $('fastRevBtn'), 'unavail' );
     if ( action )
-    {
-        var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_PAUSE, onComplete: getCmdResponse } );
-        streamReq.request();
-    }
+        streamReq.send( streamParms+"&command="+CMD_PAUSE );
 }
 
 function streamPlay( action )
 {
     setButtonState( $('pauseBtn'), 'inactive' );
-    setButtonState( $('playBtn'), streamStatus.rate==1?'active':'inactive' );
+    if (streamStatus)
+        setButtonState( $('playBtn'), streamStatus.rate==1?'active':'inactive' );
     setButtonState( $('fastFwdBtn'), 'inactive' );
     setButtonState( $('slowFwdBtn'), 'unavail' );
     setButtonState( $('slowRevBtn'), 'unavail' );
     setButtonState( $('fastRevBtn'), 'inactive' );
     if ( action )
     {
-        var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_PLAY, onComplete: getCmdResponse } );
-        streamReq.request();
+        streamReq.send( streamParms+"&command="+CMD_PLAY );
     }
 }
 
@@ -113,10 +114,7 @@ function streamFastFwd( action )
     setButtonState( $('slowRevBtn'), 'unavail' );
     setButtonState( $('fastRevBtn'), 'inactive' );
     if ( action )
-    {
-        var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_FASTFWD, onComplete: getCmdResponse } );
-        streamReq.request();
-    }
+        streamReq.send( streamParms+"&command="+CMD_FASTFWD );
 }
 
 function streamSlowFwd( action )
@@ -128,10 +126,7 @@ function streamSlowFwd( action )
     setButtonState( $('slowRevBtn'), 'inactive' );
     setButtonState( $('fastRevBtn'), 'unavail' );
     if ( action )
-    {
-        var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_SLOWFWD, onComplete: getCmdResponse } );
-        streamReq.request();
-    }
+        streamReq.send( streamParms+"&command="+CMD_SLOWFWD );
     setButtonState( $('pauseBtn'), 'active' );
     setButtonState( $('slowFwdBtn'), 'inactive' );
 }
@@ -145,10 +140,7 @@ function streamSlowRev( action )
     setButtonState( $('slowRevBtn'), 'active' );
     setButtonState( $('fastRevBtn'), 'unavail' );
     if ( action )
-    {
-        var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_SLOWREV, onComplete: getCmdResponse } );
-        streamReq.request();
-    }
+        streamReq.send( streamParms+"&command="+CMD_SLOWREV );
     setButtonState( $('pauseBtn'), 'active' );
     setButtonState( $('slowRevBtn'), 'inactive' );
 }
@@ -162,142 +154,129 @@ function streamFastRev( action )
     setButtonState( $('slowRevBtn'), 'unavail' );
     setButtonState( $('fastRevBtn'), 'inactive' );
     if ( action )
-    {
-        var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_FASTREV, onComplete: getCmdResponse } );
-        streamReq.request();
-    }
+        streamReq.send( streamParms+"&command="+CMD_FASTREV );
 }
 
 function streamPrev( action )
 {
     streamPlay( false );
     if ( action )
-    {
-        var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_PREV, onComplete: getCmdResponse } );
-        streamReq.request();
-    }
+        streamReq.send( streamParms+"&command="+CMD_PREV );
 }
 
 function streamNext( action )
 {
     streamPlay( false );
     if ( action )
-    {
-        var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_NEXT, onComplete: getCmdResponse } );
-        streamReq.request();
-    }
+        streamReq.send( streamParms+"&command="+CMD_NEXT );
 }
 
 function streamZoomIn( x, y )
 {
-    var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_ZOOMIN+"&x="+x+"&y="+y, onComplete: getCmdResponse } );
-    streamReq.request();
+    streamReq.send( streamParms+"&command="+CMD_ZOOMIN+"&x="+x+"&y="+y );
 }
 
 function streamZoomOut()
 {
-    var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_ZOOMOUT, onComplete: getCmdResponse } );
-    streamReq.request();
+    streamReq.send( streamParms+"&command="+CMD_ZOOMOUT );
 }
 
 function streamScale( scale )
 {
-    var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_SCALE+"&scale="+scale, onComplete: getCmdResponse } );
-    streamReq.request();
+    streamReq.send( streamParms+"&command="+CMD_SCALE+"&scale="+scale );
 }
 
 function streamPan( x, y )
 {
-    var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_PAN+"&x="+x+"&y="+y, onComplete: getCmdResponse } );
-    streamReq.request();
+    streamReq.send( streamParms+"&command="+CMD_PAN+"&x="+x+"&y="+y );
 }
 
 function streamSeek( offset )
 {
-    var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_SEEK+"&offset="+offset, onComplete: getCmdResponse } );
-    streamReq.request();
+    streamReq.send( streamParms+"&command="+CMD_SEEK+"&offset="+offset );
 }
 
 function streamQuery()
 {       
-    var streamReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: streamParms+"&command="+CMD_QUERY, onComplete: getCmdResponse } );
-    streamReq.request();
+    streamReq.send( streamParms+"&command="+CMD_QUERY );
 }       
 
 var slider = null;
 var scroll = null;
 
-function getEventResponse( respText )
+function getEventResponse( respObj, respText )
 {
-    if ( respText == 'Ok' )
+    if ( checkStreamForErrors( "getEventResponse", respObj ) )
         return;
-    var response = Json.evaluate( respText );
 
-    event = response.event;
-    if ( !$('eventStills').hasClass( 'hidden' ) && currEventId != event.Id )
+    eventData = respObj.event;
+    if ( !$('eventStills').hasClass( 'hidden' ) && currEventId != eventData.Id )
         resetEventStills();
-    currEventId = event.Id;
+    currEventId = eventData.Id;
 
-    $('dataId').setHTML( event.Id );
-    if ( event.Notes )
+    $('dataId').set( 'text', eventData.Id );
+    if ( eventData.Notes )
     {
-        $('dataCause').setProperty( 'title', event.Notes );
+        $('dataCause').setProperty( 'title', eventData.Notes );
     }
     else
     {
         $('dataCause').setProperty( 'title', causeString );
     }
-    $('dataCause').setHTML( event.Cause );
-    $('dataTime').setHTML( event.StartTime );
-    $('dataDuration').setHTML( event.Length );
-    $('dataFrames').setHTML( event.Frames+"/"+event.AlarmFrames );
-    $('dataScore').setHTML( event.TotScore+"/"+event.AvgScore+"/"+event.MaxScore );
-    $('eventName').setProperty( 'value', event.Name );
+    $('dataCause').set( 'text', eventData.Cause );
+    $('dataTime').set( 'text', eventData.StartTime );
+    $('dataDuration').set( 'text', eventData.Length );
+    $('dataFrames').set( 'text', eventData.Frames+"/"+eventData.AlarmFrames );
+    $('dataScore').set( 'text', eventData.TotScore+"/"+eventData.AvgScore+"/"+eventData.MaxScore );
+    $('eventName').setProperty( 'value', eventData.Name );
 
-    if ( parseInt(event.Archived) )
+    if ( canEditEvents )
     {
-        $('archiveEvent').addClass( 'hidden' );
-        $('unarchiveEvent').removeClass( 'hidden' );
-    }
-    else
-    {
-        $('archiveEvent').removeClass( 'hidden' );
-        $('unarchiveEvent').addClass( 'hidden' );
+        if ( parseInt(eventData.Archived) )
+        {
+            $('archiveEvent').addClass( 'hidden' );
+            $('unarchiveEvent').removeClass( 'hidden' );
+        }
+        else
+        {
+            $('archiveEvent').removeClass( 'hidden' );
+            $('unarchiveEvent').addClass( 'hidden' );
+        }
     }
     //var eventImg = $('eventImage');
-    //eventImg.setStyles( { 'width': event.width, 'height': event.height } );
+    //eventImg.setStyles( { 'width': eventData.width, 'height': eventData.height } );
     drawProgressBar();
-    nearEventsQuery( event.Id );
+    nearEventsQuery( eventData.Id );
 }
 
+var eventReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, link: 'cancel', onSuccess: getEventResponse } );
+
 function eventQuery( eventId )
 {
     var eventParms = "view=request&request=status&entity=event&id="+eventId;
-    var eventReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: eventParms, onComplete: getEventResponse } );
-    eventReq.request();
+    eventReq.send( eventParms );
 }
 
 var prevEventId = 0;
 var nextEventId = 0;
 
-function getNearEventsResponse( respText )
+function getNearEventsResponse( respObj, respText )
 {
-    if ( respText == 'Ok' )
+    if ( checkStreamForErrors( "getNearEventsResponse", respObj ) )
         return;
-    var response = Json.evaluate( respText );
-
-    prevEventId = response.nearevents.PrevEventId;
-    nextEventId = response.nearevents.NextEventId;
+    prevEventId = respObj.nearevents.PrevEventId;
+    nextEventId = respObj.nearevents.NextEventId;
 
     $('prevEventBtn').disabled = !prevEventId;
     $('nextEventBtn').disabled = !nextEventId;
 }
 
+var nearEventsReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, link: 'cancel', onSuccess: getNearEventsResponse } );
+
 function nearEventsQuery( eventId )
 {
     var parms = "view=request&request=status&entity=nearevents&id="+eventId;
-    var query = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: parms, onComplete: getNearEventsResponse } );
-    query.request();
+    nearEventsReq.send( parms );
 }
 
 var frameBatch = 40;
@@ -310,7 +289,7 @@ function loadEventThumb( event, frame, loadImage )
         console.error( "No holder found for frame "+frame.FrameId );
         return;
     }
-    var img = new Asset.image( frame.Image.imagePath,
+    var img = new Asset.image( imagePrefix+frame.Image.imagePath,
         {
             'onload': ( function( loadImage )
                 {
@@ -318,7 +297,7 @@ function loadEventThumb( event, frame, loadImage )
                     thumbImg.removeClass( 'placeholder' );
                     thumbImg.setProperty( 'class', frame.Type=='Alarm'?'alarm':'normal' );
                     thumbImg.setProperty( 'title', frame.FrameId+' / '+((frame.Type=='Alarm')?frame.Score:0) );
-                    thumbImg.removeEvent( 'click' );
+                    thumbImg.removeEvents( 'click' );
                     thumbImg.addEvent( 'click', function() { locateImage( frame.FrameId, true ); } );
                     if ( loadImage )
                         loadEventImage( event, frame );
@@ -327,27 +306,24 @@ function loadEventThumb( event, frame, loadImage )
     );
 }
 
-function updateStillsSizes()
+function updateStillsSizes( noDelay )
 {
-    var containerDim = $('eventThumbs').getStyles( 'width', 'height' );
-    var popupDim = $('eventImageFrame').getStyles( 'width', 'height' );
-    console.log( containerDim );
-    console.log( popupDim );
+    var containerDim = $('eventThumbs').getSize();
 
-    var containerWidth = containerDim.width.match( /^\d+/ );
-    var containerHeight = containerDim.height.match( /^\d+/ );
-    //var popupWidth = popupDim.width.match( /^\d+/ );
-    //var popupHeight = popupDim.height.match( /^\d+/ );
-    var popupWidth = $('eventImage').width;
-    var popupHeight = $('eventImage').height;
+    var containerWidth = containerDim.x;
+    var containerHeight = containerDim.y;
+    var popupWidth = parseInt($('eventImage').getStyle( 'width' ));
+    var popupHeight = parseInt($('eventImage').getStyle( 'height' ));
 
     var left = (containerWidth - popupWidth)/2;
     if ( left < 0 ) left = 0;
     var top = (containerHeight - popupHeight)/2;
     if ( top < 0 ) top = 0;
-
-    console.log( "Top: "+top+", Left: "+left );
-
+    if ( popupHeight == 0 && !noDelay ) // image not yet loaded lets give it another second
+    {
+        updateStillsSizes.pass( true ).delay( 50 );
+        return;
+    }
     $('eventImagePanel').setStyles( {
         'left': left,
         'top': top
@@ -356,7 +332,7 @@ function updateStillsSizes()
 
 function loadEventImage( event, frame )
 {
-    console.log( "Loading "+event.Id+"/"+frame.FrameId );
+    console.debug( "Loading "+event.Id+"/"+frame.FrameId );
     var eventImg = $('eventImage');
     var thumbImg = $('eventThumb'+frame.FrameId);
     if ( eventImg.getProperty( 'src' ) != thumbImg.getProperty( 'src' ) )
@@ -378,6 +354,7 @@ function loadEventImage( event, frame )
             'width': event.Width,
             'height': event.Height
         } );
+        $('eventImageBar').setStyle( 'width', event.Width );
         if ( frame.Type=='Alarm' )
             $('eventImageStats').removeClass( 'hidden' );
         else
@@ -390,10 +367,10 @@ function loadEventImage( event, frame )
             eventImagePanel.setOpacity( 0 );
             updateStillsSizes();
             eventImagePanel.setStyle( 'display', 'block' );
-            new Fx.Style( eventImagePanel, 'opacity',{ duration: 500, transition: Fx.Transitions.sineInOut } ).start( 0, 1 );
+            new Fx.Tween( eventImagePanel, { duration: 500, transition: Fx.Transitions.Sine } ).start( 'opacity', 0, 1 );
         }
 
-        $('eventImageNo').setText( frame.FrameId );
+        $('eventImageNo').set( 'text', frame.FrameId );
         $('prevImageBtn').disabled = (frame.FrameId==1);
         $('nextImageBtn').disabled = (frame.FrameId==event.Frames);
     }
@@ -414,7 +391,7 @@ function hideEventImageComplete()
 function hideEventImage()
 {
     if ( $('eventImagePanel').getStyle( 'display' ) != 'none' )
-        new Fx.Style( $('eventImagePanel'), 'opacity',{ duration: 500, transition: Fx.Transitions.sineInOut, onComplete: hideEventImageComplete } ).start( 1, 0 );
+        new Fx.Tween( $('eventImagePanel'), { duration: 500, transition: Fx.Transitions.Sine, onComplete: hideEventImageComplete } ).start( 'opacity', 1, 0 );
 }
 
 function resetEventStills()
@@ -424,68 +401,66 @@ function resetEventStills()
     if ( true || !slider )
     {
         slider = new Slider( $('thumbsSlider'), $('thumbsKnob'), {
-            steps: event.Frames,
+            /*steps: eventData.Frames,*/
             onChange: function( step )
             {
-                var fid = step + 1;
-                console.log( 'FID:'+step );
-                checkFrames( event.Id, fid );
+                if ( !step )
+                    step = 0;
+                var fid = parseInt((step * eventData.Frames)/this.options.steps);
+                if ( fid < 1 )
+                    fid = 1;
+                else if ( fid > eventData.Frames )
+                    fid = eventData.Frames;
+                checkFrames( eventData.Id, fid );
                 scroll.toElement( 'eventThumb'+fid );
             }
         } ).set( 0 );
     }
-    console.log( "H1: "+$('eventThumbs').getStyle( 'height' ).match( /^\d+/ ) );
-    console.log( "H2 :"+(event.Height+80) );
-    if ( $('eventThumbs').getStyle( 'height' ).match( /^\d+/ ) < (parseInt(event.Height)+80) )
-    {
-        console.log( "Resizing" );
-        $('eventThumbs').setStyle( 'height', (parseInt(event.Height)+80)+'px' );
-    }
+    if ( $('eventThumbs').getStyle( 'height' ).match( /^\d+/ ) < (parseInt(eventData.Height)+80) )
+        $('eventThumbs').setStyle( 'height', (parseInt(eventData.Height)+80)+'px' );
 }
 
-function getFrameResponse( respText )
+function getFrameResponse( respObj, respText )
 {
-    if ( respText == 'Ok' )
+    if ( checkStreamForErrors( "getFrameResponse", respObj ) )
         return;
-    var response = Json.evaluate( respText );
 
-    var frame = response.frameimage;
+    var frame = respObj.frameimage;
 
-    //console.log( 'Got response for frame '+frame.FrameId );
-
-    if ( !event )
+    if ( !eventData )
     {
         console.error( "No event "+frame.EventId+" found" );
         return;
     }
 
-    if ( !event['frames'] )
-        event['frames'] = new Object();
+    if ( !eventData['frames'] )
+        eventData['frames'] = new Hash();
 
-    event['frames'][frame.FrameId] = frame;
+    eventData['frames'][frame.FrameId] = frame;
     
-    loadEventThumb( event, frame, response.loopback=="true" );
+    loadEventThumb( eventData, frame, respObj.loopback=="true" );
 }
 
+var frameReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, link: 'chain', onSuccess: getFrameResponse } );
+
 function frameQuery( eventId, frameId, loadImage )
 {
     var parms = "view=request&request=status&entity=frameimage&id[0]="+eventId+"&id[1]="+frameId+"&loopback="+loadImage;
-    var req = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: parms, onComplete: getFrameResponse } );
-    req.request();
+    frameReq.send( parms );
 }
 
 var currFrameId = null;
 
 function checkFrames( eventId, frameId, loadImage )
 {
-    if ( !event )
+    if ( !eventData )
     {
         console.error( "No event "+eventId+" found" );
         return;
     }
 
-    if ( !event['frames'] )
-        event['frames'] = new Object();
+    if ( !eventData['frames'] )
+        eventData['frames'] = new Hash();
 
     currFrameId = frameId;
 
@@ -493,23 +468,20 @@ function checkFrames( eventId, frameId, loadImage )
     if ( loFid < 1 )
         loFid = 1;
     var hiFid = loFid + (frameBatch-1);
-    if ( hiFid > event.Frames )
-        hiFid = event.Frames;
+    if ( hiFid > eventData.Frames )
+        hiFid = eventData.Frames;
 
     for ( var fid = loFid; fid <= hiFid; fid++ )
     {
-        console.log( 'Checking frame '+fid );
         if ( !$('eventThumb'+fid) )
         {
-            console.log( 'Creating frame placeholder '+fid );
             var img = new Element( 'img', { 'id': 'eventThumb'+fid, 'src': 'graphics/transparent.gif', 'alt': fid, 'class': 'placeholder' } );
-            img.addEvent( 'click', function () { event['frames'][fid] = null; checkFrames( eventId, frameId ) } );
+            img.addEvent( 'click', function () { eventData['frames'][fid] = null; checkFrames( eventId, fid ) } );
             frameQuery( eventId, fid, loadImage && (fid == frameId) );
             var imgs = $('eventThumbs').getElements( 'img' );
             var injected = false;
             if ( fid < imgs.length )
             {
-                //console.log( "Injecting "+fid+" at "+(fid-1)+", length "+imgs.length );
                 img.injectBefore( imgs[fid-1] );
                 injected = true;
             }
@@ -520,7 +492,6 @@ function checkFrames( eventId, frameId, loadImage )
                     {
                         if ( parseInt(img.getProperty( 'alt' )) < parseInt(thumbImg.getProperty( 'alt' )) )
                         {
-                            //console.log( "Injecting "+fid+" at index "+index+", length "+imgs.length );
                             img.injectBefore( thumbImg );
                             return( true );
                         }
@@ -530,26 +501,31 @@ function checkFrames( eventId, frameId, loadImage )
             }
             if ( !injected )
             {
-                //console.log( "Injecting "+fid+", length "+imgs.length );
                 img.injectInside( $('eventThumbs') );
             }
+            var scale = parseInt(img.getStyle('height'));
+            img.setStyles( {
+                'width': parseInt((eventData.Width*scale)/100),
+                'height': parseInt((eventData.Height*scale)/100)
+            } );
         }
-        else if ( event['frames'][fid] )
+        else if ( eventData['frames'][fid] )
         {
             if ( loadImage && (fid == frameId) )
             {
-                loadEventImage( event, event['frames'][fid] );
+                loadEventImage( eventData, eventData['frames'][fid], loadImage );
             }
         }
     }
     $('prevThumbsBtn').disabled = (frameId==1);
-    $('nextThumbsBtn').disabled = (frameId==event.Frames);
+    $('nextThumbsBtn').disabled = (frameId==eventData.Frames);
 }
 
 function locateImage( frameId, loadImage )
 {
-    slider.fireEvent( 'onTick', slider.toPosition( frameId-1 ));
-    checkFrames( event.Id, frameId, loadImage );
+    if ( slider )
+        slider.fireEvent( 'tick', slider.toPosition( parseInt((frameId-1)*slider.options.steps/eventData.Frames) ));
+    checkFrames( eventData.Id, frameId, loadImage );
     scroll.toElement( 'eventThumb'+frameId );
 }
 
@@ -561,20 +537,20 @@ function prevImage()
 
 function nextImage()
 {
-    if ( currFrameId < event.Frames )
+    if ( currFrameId < eventData.Frames )
         locateImage( parseInt(currFrameId)+1, true );
 }
 
 function prevThumbs()
 {
     if ( currFrameId > 1 )
-        locateImage( currFrameId>10?(currFrameId-10):1, !$('eventImagePanel').hasClass( 'hidden' ) );
+        locateImage( parseInt(currFrameId)>10?(parseInt(currFrameId)-10):1, $('eventImagePanel').getStyle('display')!="none" );
 }
 
 function nextThumbs()
 {
-    if ( currFrameId < event.Frames )
-        locateImage( currFrameId<(event.Frames-10)?(currFrameId+10):event.Frames, !$('eventImagePanel').hasClass( 'hidden' ) );
+    if ( currFrameId < eventData.Frames )
+        locateImage( parseInt(currFrameId)<(eventData.Frames-10)?(parseInt(currFrameId)+10):eventData.Frames, $('eventImagePanel').getStyle('display')!="none" );
 }
 
 function prevEvent()
@@ -595,28 +571,26 @@ function nextEvent()
     }
 }
 
-function getActResponse( respText )
+function getActResponse( respObj, respText )
 {
-    if ( respText == 'Ok' )
+    if ( checkStreamForErrors( "getActResponse", respObj ) )
         return;
-    var response = Json.evaluate( respText );
 
-    if ( response.refreshParent )
+    if ( respObj.refreshParent )
         refreshParentWindow();
 
-    if ( response.refreshEvent )
-        eventQuery( event.Id );
+    if ( respObj.refreshEvent )
+        eventQuery( eventData.Id );
 }
 
+var actReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, link: 'cancel', onSuccess: getActResponse } );
+
 function actQuery( action, parms )
 {
-    var actParms = "view=request&request=event&id="+event.Id+"&action="+action;
+    var actParms = "view=request&request=event&id="+eventData.Id+"&action="+action;
     if ( parms != null )
-    {
-        actParms += "&"+Object.toQueryString( parms );
-    }
-    var actReq = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: actParms, onComplete: getActResponse } );
-    actReq.request();
+        actParms += "&"+Hash.toQueryString( parms );
+    actReq.send( actParms );
 }
 
 function deleteEvent()
@@ -627,18 +601,18 @@ function deleteEvent()
 
 function renameEvent()
 {
-    var newName = $('eventName').getValue();
+    var newName = $('eventName').get('value');
     actQuery( 'rename', { eventName: newName } );
 }
 
 function editEvent()
 {
-    createPopup( '?view=eventdetail&eid='+event.Id, 'zmEventDetail', 'eventdetail' );
+    createPopup( '?view=eventdetail&eid='+eventData.Id, 'zmEventDetail', 'eventdetail' );
 }
 
 function exportEvent()
 {
-    createPopup( '?view=export&eid='+event.Id, 'zmExport', 'export' );
+    createPopup( '?view=export&eid='+eventData.Id, 'zmExport', 'export' );
 }
 
 function archiveEvent()
@@ -653,7 +627,7 @@ function unarchiveEvent()
 
 function showEventFrames()
 {
-    createPopup( '?view=frames&eid='+event.Id, 'zmFrames', 'frames' );
+    createPopup( '?view=frames&eid='+eventData.Id, 'zmFrames', 'frames' );
 }
 
 function showStream()
@@ -689,13 +663,13 @@ function showStills()
 
 function showFrameStats()
 {
-    var fid = $('eventImageNo').getText();
-    createPopup( '?view=stats&eid='+event.Id+'&fid='+fid, 'zmStats', 'stats', event.Width, event.Height );
+    var fid = $('eventImageNo').get('text');
+    createPopup( '?view=stats&eid='+eventData.Id+'&fid='+fid, 'zmStats', 'stats', eventData.Width, eventData.Height );
 }
 
 function videoEvent()
 {
-    createPopup( '?view=video&eid='+event.Id, 'zmVideo', 'video', event.Width, event.Height );
+    createPopup( '?view=video&eid='+eventData.Id, 'zmVideo', 'video', eventData.Width, eventData.Height );
 }
 
 function drawProgressBar()
@@ -703,7 +677,7 @@ function drawProgressBar()
     var barWidth = 0;
     $('progressBar').addClass( 'invisible' );
     var cells = $('progressBar').getElements( 'div' );
-    var cellWidth = parseInt( event.Width/$$(cells).length );
+    var cellWidth = parseInt( eventData.Width/$$(cells).length );
     $$(cells).forEach(
         function( cell, index )
         {
@@ -711,7 +685,7 @@ function drawProgressBar()
                 $(cell).setStyles( { 'left': barWidth, 'width': cellWidth, 'borderLeft': 0 } );
             else
                 $(cell).setStyles( { 'left': barWidth, 'width': cellWidth } );
-            var offset = parseInt((index*event.Length)/$$(cells).length);
+            var offset = parseInt((index*eventData.Length)/$$(cells).length);
             $(cell).setProperty( 'title', '+'+secsToTime(offset)+'s' );
             $(cell).removeEvent( 'click' );
             $(cell).addEvent( 'click', function(){ streamSeek( offset ); } );
@@ -724,10 +698,10 @@ function drawProgressBar()
 
 function updateProgressBar()
 {
-    if ( event && streamStatus )
+    if ( eventData && streamStatus )
     {
         var cells = $('progressBar').getElements( 'div' );
-        var completeIndex = parseInt((($$(cells).length+1)*streamStatus.progress)/event.Length);
+        var completeIndex = parseInt((($$(cells).length+1)*streamStatus.progress)/eventData.Length);
         $$(cells).forEach(
             function( cell, index )
             {
@@ -765,7 +739,7 @@ function handleClick( event )
 function initPage()
 {
     streamCmdTimer = streamQuery.delay( 250 );
-    eventQuery.pass( event.Id ).delay( 500 );
+    eventQuery.pass( eventData.Id ).delay( 500 );
 
     if ( canStreamNative )
     {
