@@ -75,8 +75,8 @@ function frameDataResponse( respObj, respText )
     loadEventImage( frame.Image.imagePath, event.Id, frame.FrameId, event.Width, event.Height );
 }
 
-var eventQuery = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, autoCancel: true, onComplete: eventDataResponse } );
-var frameQuery = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, autoCancel: true, onComplete: frameDataResponse } );
+var eventQuery = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, link: 'cancel', onSuccess: eventDataResponse } );
+var frameQuery = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, link: 'cancel', onSuccess: frameDataResponse } );
 
 function requestFrameData( eventId, frameId )
 {
@@ -112,7 +112,7 @@ function previewEvent( eventId, frameId )
 function loadEventImage( imagePath, eid, fid, width, height )
 {
     var imageSrc = $('imageSrc');
-    imageSrc.setProperty( 'src', imagePath );
+    imageSrc.setProperty( 'src', imagePrefix+imagePath );
     imageSrc.removeEvent( 'click' );
     imageSrc.addEvent( 'click', showEvent.pass( [ eid, fid, width, height ] ) );
     var eventData = $('eventData');
