@@ -100,7 +100,7 @@ function setAlarmState( currentAlarmState )
 }
 
 var streamCmdParms = "view=request&request=stream&connkey="+connKey;
-var streamCmdReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, onSuccess: getStreamCmdResponse } );
+var streamCmdReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, link: 'cancel', onSuccess: getStreamCmdResponse } );
 var streamCmdTimer = null;
 
 var streamStatus;
@@ -352,7 +352,7 @@ function streamCmdQuery()
 }       
 
 var statusCmdParms = "view=request&request=status&entity=monitor&id="+monitorId+"&element[]=Status&element[]=FrameRate";
-var statusCmdReq = new Request.JSON( { url: thisUrl, method: 'post', data: statusCmdParms, timeout: AJAX_TIMEOUT, onSuccess: getStatusCmdResponse } );
+var statusCmdReq = new Request.JSON( { url: thisUrl, method: 'post', data: statusCmdParms, timeout: AJAX_TIMEOUT, link: 'cancel', onSuccess: getStatusCmdResponse } );
 var statusCmdTimer = null;
 
 function getStatusCmdResponse( respObj, respText )
@@ -381,7 +381,7 @@ function statusCmdQuery()
 }       
 
 var alarmCmdParms = "view=request&request=alarm&id="+monitorId;
-var alarmCmdReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, onSuccess: getAlarmCmdResponse, onTimeout: streamCmdQuery } );
+var alarmCmdReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, link: 'cancel', onSuccess: getAlarmCmdResponse, onTimeout: streamCmdQuery } );
 var alarmCmdFirst = true;
 
 function getAlarmCmdResponse( respObj, respText )
@@ -430,7 +430,7 @@ function deleteEvent( event, eventId )
 }
 
 var eventCmdParms = "view=request&request=status&entity=events&id="+monitorId+"&count="+maxDisplayEvents+"&sort=Id%20desc";
-var eventCmdReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, data: eventCmdParms, onSuccess: getEventCmdResponse, onTimeout: eventCmdQuery } );
+var eventCmdReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, data: eventCmdParms, link: 'cancel', onSuccess: getEventCmdResponse, onTimeout: eventCmdQuery } );
 var eventCmdTimer = null;
 var eventCmdFirst = true;
 
@@ -549,7 +549,7 @@ function eventCmdQuery()
 }
 
 var controlParms = "view=request&request=control&id="+monitorId;
-var controlReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, onSuccess: getControlResponse } );
+var controlReq = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, link: 'cancel', onSuccess: getControlResponse } );
 
 function getControlResponse( respObj, respText )
 {
@@ -710,9 +710,13 @@ function initPage()
         var streamImg = $('imageFeed').getElement('img');
         if ( !streamImg )
             streamImg = $('imageFeed').getElement('object');
-        $(streamImg).addEvent( 'click', handleClick.bindWithEvent( $(streamImg) ) );
         if ( streamMode == "single" )
+        {
+            streamImg.addEvent( 'click', fetchImage.pass( streamImg ) );
             fetchImage.pass( streamImg ).periodical( imageRefreshTimeout );
+        }
+        else
+            streamImg.addEvent( 'click', handleClick.bindWithEvent( streamImg ) );
     }
 
     if ( refreshApplet && appletRefreshTime )
