@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web options view file, $Date: 2009-02-19 14:17:33 +0000 (Thu, 19 Feb 2009) $, $Revision: 2782 $
+// ZoneMinder web options view file, $Date: 2011-02-19 20:25:54 +0000 (Sat, 19 Feb 2011) $, $Revision: 3306 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -27,6 +27,7 @@ if ( !canView( 'System' ) )
 $canEdit = canEdit( 'System' );
 
 $tabs = array();
+$tabs['skins'] = $SLANG['Display']; // change me to be supported by SLANG...
 $tabs['system'] = $SLANG['System'];
 $tabs['config'] = $SLANG['Config'];
 $tabs['paths'] = $SLANG['Paths'];
@@ -41,6 +42,7 @@ $tabs['highband'] = $SLANG['HighBW'];
 $tabs['medband'] = $SLANG['MediumBW'];
 $tabs['lowband'] = $SLANG['LowBW'];
 $tabs['phoneband'] = $SLANG['PhoneBW'];
+$tabs['eyeZm'] = "eyeZm";
 if ( ZM_OPT_USE_AUTH )
     $tabs['users'] = $SLANG['Users'];
 
@@ -72,7 +74,7 @@ foreach ( $tabs as $name=>$value )
     else
     {
 ?>
-        <li><a href="?view=<?= $view ?>&tab=<?= $name ?>"><?= $value ?></a></li>
+        <li><a href="?view=<?= $view ?>&amp;tab=<?= $name ?>"><?= $value ?></a></li>
 <?php
     }
 }
@@ -80,7 +82,42 @@ foreach ( $tabs as $name=>$value )
       </ul>
       <div class="clear"></div>
 <?php 
-if ( $tab == "users" )
+if($tab == 'skins') {
+	$current_skin = $_COOKIE['zmSkin'];
+	if (isset($_GET['skin-choice'])) {
+		setcookie('zmSkin',$_GET['skin-choice']);
+		//header("Location: index.php?view=options&tab=skins&reset_parent=1");
+		echo '<script type="text/javascript">window.opener.location.reload();window.location.reload();</script>';
+	}
+
+?>
+	<form name="optionsForm" method="get" action="<?= $_SERVER['PHP_SELF'] ?>">
+        <input type="hidden" name="view" value="<?= $view ?>"/>
+        <input type="hidden" name="tab" value="<?= $tab ?>"/>
+		<table class="contentTable major optionTable" cellspacing="0">
+			<thead><tr><th><?= $SLANG['Name'] ?></th><th><?= $SLANG['Description'] ?></th> <th><?= $SLANG['Value'] ?></th></tr></thead>
+			<tbody>
+			<td>ZM_SKIN</td>
+			<td><?php echo $SLANG['SkinDescription']; ?></td>
+			<td><select name="skin-choice">
+				<?php
+					foreach(glob('skins/*',GLOB_ONLYDIR) as $dir) {
+						$dir = basename($dir);
+						echo '<option value="'.$dir.'" '.($current_skin==$dir ? 'SELECTED' : '').'>'.$dir.'</option>';
+					}
+				?>
+				</select>
+			</td>
+		</table>
+        <div id="contentButtons">
+          <input type="submit" value="<?= $SLANG['Save'] ?>"<?= $canEdit?'':' disabled="disabled"' ?>/>
+		  <input type="button" value="<?= $SLANG['Cancel'] ?>" onclick="closeWindow();"/>
+        </div>
+     </form>
+	
+      <?php
+}
+elseif ( $tab == "users" )
 {
 ?>
       <form name="userForm" method="post" action="<?= $_SERVER['PHP_SELF'] ?>">
@@ -118,14 +155,14 @@ if ( $tab == "users" )
         $userMonitors = array();
         if ( !empty($row['MonitorIds']) )
         {
-            foreach ( split( ",", $row['MonitorIds'] ) as $monitorId )
+            foreach ( explode( ",", $row['MonitorIds'] ) as $monitorId )
             {
                 $userMonitors[] = $monitors[$monitorId]['Name'];
             }
         }
 ?>
             <tr>
-              <td class="colUsername"><?= makePopupLink( '?view=user&uid='.$row['Id'], 'zmUser', 'user', validHtmlStr($row['Username']).($user['Username']==$row['Username']?"*":""), $canEdit ) ?></td>
+              <td class="colUsername"><?= makePopupLink( '?view=user&amp;uid='.$row['Id'], 'zmUser', 'user', validHtmlStr($row['Username']).($user['Username']==$row['Username']?"*":""), $canEdit ) ?></td>
               <td class="colLanguage"><?= $row['Language']?validHtmlStr($row['Language']):'default' ?></td>
               <td class="colEnabled"><?= $row['Enabled']?$SLANG['Yes']:$SLANG['No'] ?></td>
               <td class="colStream"><?= validHtmlStr($row['Stream']) ?></td>
@@ -143,7 +180,7 @@ if ( $tab == "users" )
           </tbody>
         </table>
         <div id="contentButtons">
-          <input type="button" value="<?= $SLANG['AddNewUser'] ?>" onclick="createPopup( '?view=user&uid=0', 'zmUser', 'user' );"<?php if ( !canEdit( 'System' ) ) { ?> disabled="disabled"<?php } ?>/><input type="submit" name="deleteBtn" value="<?= $SLANG['Delete'] ?>" disabled="disabled"/><input type="button" value="<?= $SLANG['Cancel'] ?>" onclick="closeWindow();"/>
+          <input type="button" value="<?= $SLANG['AddNewUser'] ?>" onclick="createPopup( '?view=user&amp;uid=0', 'zmUser', 'user' );"<?php if ( !canEdit( 'System' ) ) { ?> disabled="disabled"<?php } ?>/><input type="submit" name="deleteBtn" value="<?= $SLANG['Delete'] ?>" disabled="disabled"/><input type="button" value="<?= $SLANG['Cancel'] ?>" onclick="closeWindow();"/>
         </div>
       </form>
 <?php
@@ -177,7 +214,7 @@ else
 ?>
             <tr>
               <td><?= $shortName ?></td>
-              <td><?= validHtmlStr($optionPromptText) ?>&nbsp;(<?= makePopupLink( '?view=optionhelp&option='.$name, 'zmOptionHelp', 'optionhelp', '?' ) ?>)</td>
+              <td><?= validHtmlStr($optionPromptText) ?>&nbsp;(<?= makePopupLink( '?view=optionhelp&amp;option='.$name, 'zmOptionHelp', 'optionhelp', '?' ) ?>)</td>
 <?php   
         if ( $value['Type'] == "boolean" )
         {
@@ -190,7 +227,7 @@ else
 ?>
               <td class="nowrap">
 <?php
-            $options = split( "\|", $value['Hint'] );
+            $options = explode( '|', $value['Hint'] );
             if ( count( $options ) > 3 )
             {
 ?>
